@@ -34,6 +34,7 @@ package Maintainers;
 	'jand'		=> 'Jan Dubois <jand@activestate.com>',
 	'jdhedden'	=> 'Jerry D. Hedden <jdhedden@cpan.org>',
 	'jhi'		=> 'Jarkko Hietaniemi <jhi@cpan.org>',
+	'jjore'		=> 'Joshua ben Jore <jjore@cpan.org>',
 	'jpeacock'	=> 'John Peacock <jpeacock@rowman.com>',
 	'jstowe'	=> 'Jonathan Stowe <jstowe@cpan.org>',
 	'jv'		=> 'Johan Vromans <jv@cpan.org>',
@@ -126,6 +127,14 @@ package Maintainers;
 		'CPAN'		=> 0,
 		},
 
+	'B::Lint' =>
+		{
+		'MAINTAINER'	=> 'jjore',
+		'FILES'		=> q[ext/B/B/Lint.pm ext/B/t/lint.t
+				     ext/B/t/pluglib/B/Lint/Plugin/Test.pm],
+		'CPAN'		=> 1,
+		},
+
 	'base' =>
 		{
 		'MAINTAINER'	=> 'rgarcia',
