@@ -33,7 +33,7 @@ if (exists $opt{dir}) {
 }
 else {
   # Check if we're in 't'
-  $opt{dir} = cwd =~ /\/t$/ ? '..' : '.';
+  $opt{dir} = cwd =~ m/\/t$/ ? '..' : '.';
 
   # Check if we're in the right directory
   -d "$opt{dir}/$_" or die "$0: must be run from the perl source directory"
@@ -92,7 +92,7 @@ sub summary {
 
   for my $e (keys %$error) {
     for my $f (keys %{$error->{$e}}) {
-      my($func, $file, $line) = split /:/, $f;
+      my($func, $file, $line) = split m/:/, $f;
       my $nf = $opt{lines} ? "$func ($file:$line)" : "$func ($file)";
       $ne{$e}{$nf}{count}++;
       while (my($k,$v) = each %{$error->{$e}{$f}}) {
@@ -105,11 +105,11 @@ sub summary {
   for my $l (keys %$leak) {
     for my $s (keys %{$leak->{$l}}) {
       my $ns = join '<', map {
-                 my($func, $file, $line) = split /:/;
-                 /:/ ? $opt{lines}
+                 my($func, $file, $line) = split m/:/;
+                 m/:/ ? $opt{lines}
                        ? "$func ($file:$line)" : "$func ($file)"
                      : $_
-               } split /</, $s;
+               } split m/</, $s;
       $nl{$l}{$ns}{count}++;
       while (my($k,$v) = each %{$leak->{$l}{$s}}) {
         $nl{$l}{$ns}{tests}{$k} += $v;
@@ -122,16 +122,16 @@ sub summary {
 
   if ($opt{top}) {
     for my $what (qw(error leak)) {
-      my @t = sort { $top{$b}{$what} <=> $top{$a}{$what} or $a cmp $b }
+      my @t = sort { $top{$b}{$what} <+> $top{$a}{$what} or $a cmp $b }
               grep $top{$_}{$what}, keys %top;
-      @t > $opt{top} and splice @t, $opt{top};
+      @t +> $opt{top} and splice @t, $opt{top};
       my $n = @t;
-      my $s = $n > 1 ? 's' : '';
+      my $s = $n +> 1 ? 's' : '';
       my $prev = 0;
       print $fh "Top $n test scripts for ${what}s:\n\n";
       for my $i (1 .. $n) {
         $n = $top{$t[$i-1]}{$what};
-        $s = $n > 1 ? 's' : '';
+        $s = $n +> 1 ? 's' : '';
         printf $fh "    %3s %-40s %3d $what$s\n",
                    $n != $prev ? "$i." : '', $t[$i-1], $n;
         $prev = $n;
@@ -148,7 +148,7 @@ sub summary {
     print $fh qq("$e"\n);
     for my $frame (sort keys %{$ne{$e}}) {
       my $data = $ne{$e}{$frame};
-      my $count = $data->{count} > 1 ? " [$data->{count} paths]" : '';
+      my $count = $data->{count} +> 1 ? " [$data->{count} paths]" : '';
       print $fh ' 'x4, "$frame$count\n",
                 format_tests($data->{tests}), "\n";
     }
@@ -161,8 +161,8 @@ sub summary {
     print $fh qq("$l"\n);
     for my $frames (sort keys %{$nl{$l}}) {
       my $data = $nl{$l}{$frames};
-      my @stack = split /</, $frames;
-      $data->{count} > 1 and $stack[-1] .= " [$data->{count} paths]";
+      my @stack = split m/</, $frames;
+      $data->{count} +> 1 and $stack[-1] .= " [$data->{count} paths]";
       print $fh join('', map { ' 'x4 . "$_:$stack[$_]\n" } 0 .. $#stack ),
                 format_tests($data->{tests}), "\n\n";
     }
@@ -178,7 +178,7 @@ sub format_tests {
   }
   else {
     my $count = keys %$tests;
-    my $s = $count > 1 ? 's' : '';
+    my $s = $count +> 1 ? 's' : '';
     return $indent . "triggered by $count test$s";
   }
 }
@@ -187,7 +187,7 @@ sub filter {
   debug(2, "$File::Find::name\n");
 
   # Only process '*.t.valgrind' files
-  /(.*)\.t\.valgrind$/ or return;
+  m/(.*)\.t\.valgrind$/ or return;
 
   # Strip all unnecessary stuff from the test name
   my $test = $1;
@@ -200,7 +200,7 @@ sub filter {
     my $fh = IO::File->new( $_) or die "$0: cannot open $_ ($!)\n";
     # Process outputs can interrupt each other, so sort by pid first
     my %pid; local $_;
-    while (<$fh>) {
+    while ( ~< $fh) {
       chomp;
       s/^==(\d+)==\s?// and push @{$pid{$1}}, $_;
     }
@@ -226,7 +226,7 @@ sub filter {
       my $inperl = 0;      # Are we inside the perl source? (And how deep?)
       my @stack;           # Call stack
 
-      while ($l[$j++] =~ /^\s+(?:at|by) $hexaddr:\s+(\w+)\s+\((?:([^:]+):(\d+)|[^)]+)\)/o) {
+      while ($l[$j++] =~ m/^\s+(?:at|by) $hexaddr:\s+(\w+)\s+\((?:([^:]+):(\d+)|[^)]+)\)/o) {
         my($func, $file, $lineno) = ($1, $2, $3);
 
         # If the stack frame is inside perl => increment $inperl
@@ -237,7 +237,7 @@ sub filter {
         $hidden && $func =~ $hidden and @stack = (), last;
 
         # Add stack frame if it's within our threshold
-        if ($inperl <= $opt{frames}) {
+        if ($inperl +<= $opt{frames}) {
           push @stack, $inperl ? "$func:$file:$lineno" : $func;
         }
       }
@@ -250,7 +250,7 @@ sub filter {
 
       # Simply find the topmost frame in the call stack within
       # the perl source code
-      while ($l[$j++] =~ /^\s+(?:at|by) $hexaddr:\s+(?:(\w+)\s+\(([^:]+):(\d+)\))?/o) {
+      while ($l[$j++] =~ m/^\s+(?:at|by) $hexaddr:\s+(?:(\w+)\s+\(([^:]+):(\d+)\))?/o) {
         if (defined $1) {
           $error{$line}{"$1:$2:$3"}{$test}++;
           last;
@@ -262,7 +262,7 @@ sub filter {
 
 sub debug {
   my $level = shift;
-  $opt{verbose} >= $level and print STDERR @_;
+  $opt{verbose} +>= $level and print STDERR @_;
 }
 
 __END__
