@@ -159,7 +159,7 @@ package DB_File ;
 
 use warnings;
 use strict;
-our ($VERSION, @ISA, @EXPORT, $AUTOLOAD, $DB_BTREE, $DB_HASH, $DB_RECNO);
+our ($VERSION, @ISA, @EXPORT, $DB_BTREE, $DB_HASH, $DB_RECNO);
 our ($db_version, $use_XSLoader, $splice_end_array, $Error);
 use Carp;
 
@@ -170,7 +170,7 @@ $VERSION = "1.815" ;
     local $SIG{__WARN__} = sub {$splice_end_array = "@_";};
     my @a =(1); splice(@a, 3);
     $splice_end_array = 
-        ($splice_end_array =~ /^splice\(\) offset past end of array at /);
+        ($splice_end_array =~ m/^splice\(\) offset past end of array at /);
 }      
 
 #typedef enum { DB_BTREE, DB_HASH, DB_RECNO } DBTYPE;
@@ -226,21 +226,10 @@ push @ISA, qw(Tie::Hash Exporter);
 
 );
 
-sub AUTOLOAD {
-    my($constname);
-    ($constname = $AUTOLOAD) =~ s/.*:://;
-    my ($error, $val) = constant($constname);
-    Carp::croak $error if $error;
-    no strict 'refs';
-    *{Symbol::fetch_glob($AUTOLOAD)} = sub { $val };
-    goto &{*{Symbol::fetch_glob($AUTOLOAD)}};
-}           
-
-
 eval {
     # Make all Fcntl O_XXX constants available for importing
     require Fcntl;
-    my @O = grep /^O_/, @Fcntl::EXPORT;
+    my @O = grep m/^O_/, @Fcntl::EXPORT;
     Fcntl->import(@O);  # first we import what we want to export
     push(@EXPORT, @O);
 };
@@ -256,27 +245,27 @@ else
 sub tie_hash_or_array
 {
     my (@arg) = @_ ;
-    my $tieHASH = ( (caller(1))[3] =~ /TIEHASH/ ) ;
+    my $tieHASH = ( (caller(1))[3] =~ m/TIEHASH/ ) ;
 
     use File::Spec;
     $arg[1] = File::Spec->rel2abs($arg[1]) 
         if defined $arg[1] ;
 
     $arg[4] = tied %{ $arg[4] } 
-	if @arg >= 5 && ref $arg[4] && $arg[4] =~ /=HASH/ && tied %{ $arg[4] } ;
+	if @arg +>= 5 && ref $arg[4] && $arg[4] =~ m/=HASH/ && tied %{ $arg[4] } ;
 
-    $arg[2] = O_CREAT()^|^O_RDWR() if @arg >=3 && ! defined $arg[2];
-    $arg[3] = 0666               if @arg >=4 && ! defined $arg[3];
+    $arg[2] = O_CREAT()^|^O_RDWR() if @arg +>=3 && ! defined $arg[2];
+    $arg[3] = 0666               if @arg +>=4 && ! defined $arg[3];
 
     # make recno in Berkeley DB version 2 (or better) work like 
     # recno in version 1.
-    if ($db_version >= 4 and ! $tieHASH) {
+    if ($db_version +>= 4 and ! $tieHASH) {
         $arg[2] ^|^= O_CREAT();
     }
 
-    if ($db_version > 1 and defined $arg[4] and $arg[4] =~ /RECNO/ and 
+    if ($db_version +> 1 and defined $arg[4] and $arg[4] =~ m/RECNO/ and 
 	$arg[1] and ! -e $arg[1]) {
-	open(FH, ">$arg[1]") or return undef ;
+	open(FH, ">", "$arg[1]") or return undef ;
 	close FH ;
 	chmod $arg[3] ? $arg[3] : 0666 , $arg[1] ;
     }
@@ -319,12 +308,12 @@ sub STORESIZE
     my $length = shift ;
     my $current_length = $self->length() ;
 
-    if ($length < $current_length) {
+    if ($length +< $current_length) {
 	my $key ;
-        for ($key = $current_length - 1 ; $key >= $length ; -- $key)
+        for ($key = $current_length - 1 ; $key +>= $length ; -- $key)
 	  { $self->del($key) }
     }
-    elsif ($length > $current_length) {
+    elsif ($length +> $current_length) {
         $self->put($length-1, "") ;
     }
 }
@@ -351,9 +340,9 @@ sub SPLICE
     # 'If OFFSET is negative then it start that far from the end of
     # the array.'
     # 
-    if ($offset < 0) {
+    if ($offset +< 0) {
 	my $new_offset = $size + $offset;
-	if ($new_offset < 0) {
+	if ($new_offset +< 0) {
 	    die "Modification of non-creatable array value attempted, "
 	      . "subscript $offset";
 	}
@@ -365,7 +354,7 @@ sub SPLICE
 	$length = 0;
     }
 
-    if ($offset > $size) {
+    if ($offset +> $size) {
  	$offset = $size;
 	warnings::warnif('misc', 'splice() offset past end of array')
             if $splice_end_array;
@@ -379,10 +368,10 @@ sub SPLICE
     # 'If LENGTH is negative, leave that many elements off the end of
     # the array.'
     # 
-    if ($length < 0) {
+    if ($length +< 0) {
 	$length = $size - $offset + $length;
 
-	if ($length < 0) {
+	if ($length +< 0) {
 	    # The user must have specified a length bigger than the
 	    # length of the array passed in.  But perl's splice()
 	    # doesn't catch this, it just behaves as for length=0.
@@ -391,7 +380,7 @@ sub SPLICE
 	}
     }
 
-    if ($length > $size - $offset) {
+    if ($length +> $size - $offset) {
 	$length = $size - $offset;
     }
 
@@ -443,7 +432,7 @@ sub SPLICE
     while (defined (my $elem = shift @list)) {
 	my $old_pos = $pos;
 	my $status;
-	if ($pos >= $num_elems) {
+	if ($pos +>= $num_elems) {
 	    $status = $self->put($pos, $elem);
 	}
 	else {
