@@ -118,8 +118,8 @@ sub have_compiler {
   my $tmpfile = File::Spec->catfile(File::Spec->tmpdir, 'compilet.c');
   {
     local *FH;
-    open FH, "> $tmpfile" or die "Can't create $tmpfile: $!";
-    print FH "int boot_compilet() { return 1; }\n";
+    open FH, ">", "$tmpfile" or die "Can't create $tmpfile: $!";
+    print FH "int boot_compilet() \{ return 1; \}\n";
     close FH;
   }
 
