@@ -62,23 +62,23 @@ sub dlsyms {
 	push(@m,"
 $self->{BASEEXT}.def: Makefile.PL
 ",
-     '	$(PERL) "-I$(PERL_ARCHLIB)" "-I$(PERL_LIB)" -e \'use ExtUtils::Mksymlists; \\
-     Mksymlists("NAME" => "$(NAME)", "DLBASE" => "$(DLBASE)", ',
+     q|	$(PERL) "-I$(PERL_ARCHLIB)" "-I$(PERL_LIB)" -e 'use ExtUtils::Mksymlists; \
+     Mksymlists("NAME" => "$(NAME)", "DLBASE" => "$(DLBASE)", |,
      '"VERSION" => "$(VERSION)", "DISTNAME" => "$(DISTNAME)", ',
      '"INSTALLDIRS" => "$(INSTALLDIRS)", ',
      '"DL_FUNCS" => ',neatvalue($funcs),
      ', "FUNCLIST" => ',neatvalue($funclist),
      ', "IMPORTS" => ',neatvalue($imports),
-     ', "DL_VARS" => ', neatvalue($vars), ');\'
-');
+     ', "DL_VARS" => ', neatvalue($vars), q|);'
+|);
     }
     if ($self->{IMPORTS} && %{$self->{IMPORTS}}) {
 	# Make import files (needed for static build)
 	-d 'tmp_imp' or mkdir 'tmp_imp', 0777 or die "Can't mkdir tmp_imp";
-	open IMP, '>tmpimp.imp' or die "Can't open tmpimp.imp";
+	open IMP, ">", 'tmpimp.imp' or die "Can't open tmpimp.imp";
 	my ($name, $exp);
 	while (($name, $exp)= each %{$self->{IMPORTS}}) {
-	    my ($lib, $id) = ($exp =~ /(.*)\.(.*)/) or die "Malformed IMPORT `$exp'";
+	    my ($lib, $id) = ($exp =~ m/(.*)\.(.*)/) or die "Malformed IMPORT `$exp'";
 	    print IMP "$name $lib $id ?\n";
 	}
 	close IMP or die "Can't close tmpimp.imp";
@@ -97,7 +97,7 @@ sub static_lib {
     my $old = $self->ExtUtils::MM_Unix::static_lib();
     return $old unless $self->{IMPORTS} && %{$self->{IMPORTS}};
     
-    my @chunks = split /\n{2,}/, $old;
+    my @chunks = split m/\n{2,}/, $old;
     shift @chunks unless length $chunks[0]; # Empty lines at the start
     $chunks[0] .= <<'EOC';
 
