@@ -34,7 +34,7 @@ BEGIN {
     $Is_SunOS4  = $^O eq 'sunos';
     $Is_Solaris = $^O eq 'solaris';
     $Is_SunOS   = $Is_SunOS4 || $Is_Solaris;
-    $Is_BSD     = $^O =~ /^(?:(?:free|net|open)bsd|bsdos|interix|dragonfly)$/;
+    $Is_BSD     = $^O =~ m/^(?:(?:free|net|open)bsd|bsdos|interix|dragonfly)$/;
 }
 
 BEGIN {
@@ -194,14 +194,14 @@ sub cflags {
 		DM =>  '-DDEBUGGING -DEMBED -DMULTIPLICITY',
 		);
 
-    if ($libperl =~ /libperl(\w*)\Q$self->{LIB_EXT}/){
+    if ($libperl =~ m/libperl(\w*)\Q$self->{LIB_EXT}/){
 	$uc = uc($1);
     } else {
 	$uc = ""; # avoid warning
     }
     $perltype = $map{$uc} ? $map{$uc} : "";
 
-    if ($uc =~ /^D/) {
+    if ($uc =~ m/^D/) {
 	$optdebug = "-g";
     }
 
@@ -226,7 +226,7 @@ sub cflags {
 	my($line);
 	foreach $line (@o){
 	    chomp $line;
-	    if ($line =~ /(.*?)=\s*(.*)\s*$/){
+	    if ($line =~ m/(.*?)=\s*(.*)\s*$/){
 		$cflags{$1} = $2;
 		print STDOUT "	$1 = $2\n" if $Verbose;
 	    } else {
@@ -253,7 +253,7 @@ sub cflags {
 
     my $pollute = '';
     if ($Config{usemymalloc} and not $Config{bincompat5005}
-	and not $Config{ccflags} =~ /-DPERL_POLLUTE_MALLOC\b/
+	and not $Config{ccflags} =~ m/-DPERL_POLLUTE_MALLOC\b/
 	and $self->{PERL_MALLOC_OK}) {
 	$pollute = '$(PERL_MALLOC_DEF)';
     }
@@ -283,9 +283,9 @@ sub const_cccmd {
     return $self->{CONST_CCCMD} if $self->{CONST_CCCMD};
     return '' unless $self->needs_linking();
     return $self->{CONST_CCCMD} =
-	q{CCCMD = $(CC) -c $(PASTHRU_INC) $(INC) \\
-	$(CCFLAGS) $(OPTIMIZE) \\
-	$(PERLTYPE) $(MPOLLUTE) $(DEFINE_VERSION) \\
+	q{CCCMD = $(CC) -c $(PASTHRU_INC) $(INC) \
+	$(CCFLAGS) $(OPTIMIZE) \
+	$(PERLTYPE) $(MPOLLUTE) $(DEFINE_VERSION) \
 	$(XS_DEFINE_VERSION)};
 }
 
@@ -929,9 +929,9 @@ $(INST_DYNAMIC): $(OBJECT) $(MYEXTLIB) $(BOOTSTRAP) $(INST_ARCHAUTODIR)$(DFSEP).
 	# to link against the shared libperl library on shared perl
 	# platforms.  We peek at lddlflags to see if we need -Wl,-R
 	# or -R to add paths to the run-time library search path.
-        if ($Config{'lddlflags'} =~ /-Wl,-R/) {
+        if ($Config{'lddlflags'} =~ m/-Wl,-R/) {
             $libs .= ' -L$(PERL_INC) -Wl,-R$(INSTALLARCHLIB)/CORE -Wl,-R$(PERL_ARCHLIB)/CORE -lperl';
-        } elsif ($Config{'lddlflags'} =~ /-R/) {
+        } elsif ($Config{'lddlflags'} =~ m/-R/) {
             $libs .= ' -L$(PERL_INC) -R$(INSTALLARCHLIB)/CORE -R$(PERL_ARCHLIB)/CORE -lperl';
         }
     }
@@ -987,7 +987,7 @@ Finds the executables PERL and FULLPERL
 sub find_perl {
     my($self, $ver, $names, $dirs, $trace) = @_;
     my($name, $dir);
-    if ($trace >= 2){
+    if ($trace +>= 2){
         print "Looking for perl $ver by these names:
 @$names
 in these dirs:
@@ -996,9 +996,9 @@ in these dirs:
     }
 
     my $stderr_duped = 0;
-    local *STDERR_COPY;
+    my $stderr_copy;
     unless ($Is_BSD) {
-        if( open(STDERR_COPY, '>&STDERR') ) {
+        if( open($stderr_copy, '>&', \*STDERR) ) {
             $stderr_duped = 1;
         }
         else {
@@ -1021,11 +1021,11 @@ WARNING
             } else {                                            # foo/bar
                 $abs = $self->catfile($Curdir, $name);
             }
-            print "Checking $abs\n" if ($trace >= 2);
+            print "Checking $abs\n" if ($trace +>= 2);
             next unless $self->maybe_command($abs);
-            print "Executing $abs\n" if ($trace >= 2);
+            print "Executing $abs\n" if ($trace +>= 2);
 
-            my $version_check = qq{$abs -le "\$] >= $ver; print qq{VER_OK}"};
+            my $version_check = qq{$abs -le "\$^V =~ m/^\Q$ver\E/; print qq\{VER_OK\}"};
             $version_check = "$Config{run} $version_check"
                 if defined $Config{run} and length $Config{run};
 
@@ -1040,13 +1040,13 @@ WARNING
             } else {
                 close STDERR if $stderr_duped;
                 $val = `$version_check`;
-                open STDERR, '>&STDERR_COPY' if $stderr_duped;
+                open STDERR, '>&', $stderr_copy if $stderr_duped;
             }
 
-            if ($val =~ /^VER_OK/m) {
+            if ($val =~ m/^VER_OK/m) {
                 print "Using PERL=$abs\n" if $trace;
                 return $abs;
-            } elsif ($trace >= 2) {
+            } elsif ($trace +>= 2) {
                 print "Result: '$val' ".($? >> 8)."\n";
             }
         }
@@ -1067,16 +1067,16 @@ Inserts the sharpbang or equivalent magic number to a set of @files.
 sub fixin {    # stolen from the pink Camel book, more or less
     my ( $self, @files ) = @_;
 
-    my ($does_shbang) = $Config{'sharpbang'} =~ /^\s*\#\!/;
+    my ($does_shbang) = $Config{'sharpbang'} =~ m/^\s*\#\!/;
     for my $file (@files) {
         my $file_new = "$file.new";
         my $file_bak = "$file.bak";
 
         local (*FIXIN);
         local (*FIXOUT);
-        open( FIXIN, $file ) or croak "Can't process '$file': $!";
+        open( FIXIN, "<", $file ) or croak "Can't process '$file': $!";
         local $/ = "\n";
-        chomp( my $line = <FIXIN> );
+        chomp( my $line = ~< *FIXIN );
         next unless $line =~ s/^\s*\#!\s*//;    # Not a shbang file.
         # Now figure out the interpreter name.
         my ( $cmd, $arg ) = split ' ', $line, 2;
@@ -1121,7 +1121,7 @@ sub fixin {    # stolen from the pink Camel book, more or less
                 $shb .= "\n";
             }
             $shb .= qq{
-eval 'exec $interpreter $arg -S \$0 \${1+"\$\@"}'
+eval 'exec $interpreter $arg -S \$0 \$\{1+"\$\@"\}'
     if 0; # not running under some shell
 } unless $Is_Win32;    # this won't work on win32, so don't
         }
@@ -1131,7 +1131,7 @@ eval 'exec $interpreter $arg -S \$0 \${1+"\$\@"}'
             next;
         }
 
-        unless ( open( FIXOUT, ">$file_new" ) ) {
+        unless ( open( FIXOUT, ">", "$file_new" ) ) {
             warn "Can't create new $file: $!\n";
             next;
         }
@@ -1139,7 +1139,7 @@ eval 'exec $interpreter $arg -S \$0 \${1+"\$\@"}'
         # Print out the new #! line (or equivalent).
         local $\;
         local $/;
-        print FIXOUT $shb, <FIXIN>;
+        print FIXOUT $shb, ~< *FIXIN;
         close FIXIN;
         close FIXOUT;
 
@@ -1170,7 +1170,7 @@ sub _rename {
     my($old, $new) = @_;
 
     foreach my $file ($old, $new) {
-        if( $Is_VMS and basename($file) !~ /\./ ) {
+        if( $Is_VMS and basename($file) !~ m/\./ ) {
             # rename() in 5.8.0 on VMS will not rename a file if it
             # does not contain a dot yet it returns success.
             $file = "$file.";
@@ -1257,35 +1257,35 @@ sub init_dirscan {	# --- File and Directory Lists (.xs .pm .pod etc)
     @ignore{map lc, keys %ignore} = values %ignore if $Is_VMS;
 
     foreach $name ($self->lsdir($Curdir)){
-	next if $name =~ /\#/;
+	next if $name =~ m/\#/;
 	next if $name eq $Curdir or $name eq $Updir or $ignore{$name};
 	next unless $self->libscan($name);
 	if (-d $name){
 	    next if -l $name; # We do not support symlinks at all
             next if $self->{NORECURS};
 	    $dir{$name} = $name if (-f $self->catfile($name,"Makefile.PL"));
-	} elsif ($name =~ /\.xs\z/){
+	} elsif ($name =~ m/\.xs\z/){
 	    my($c); ($c = $name) =~ s/\.xs\z/.c/;
 	    $xs{$name} = $c;
 	    $c{$c} = 1;
-	} elsif ($name =~ /\.c(pp|xx|c)?\z/i){  # .c .C .cpp .cxx .cc
+	} elsif ($name =~ m/\.c(pp|xx|c)?\z/i){  # .c .C .cpp .cxx .cc
 	    $c{$name} = 1
 		unless $name =~ m/perlmain\.c/; # See MAP_TARGET
-	} elsif ($name =~ /\.h\z/i){
+	} elsif ($name =~ m/\.h\z/i){
 	    $h{$name} = 1;
-	} elsif ($name =~ /\.PL\z/) {
+	} elsif ($name =~ m/\.PL\z/) {
 	    ($pl_files{$name} = $name) =~ s/\.PL\z// ;
-	} elsif (($Is_VMS || $Is_Dos) && $name =~ /[._]pl$/i) {
+	} elsif (($Is_VMS || $Is_Dos) && $name =~ m/[._]pl$/i) {
 	    # case-insensitive filesystem, one dot per name, so foo.h.PL
 	    # under Unix appears as foo.h_pl under VMS or fooh.pl on Dos
-	    local($/); open(PL,$name); my $txt = <PL>; close PL;
-	    if ($txt =~ /Extracting \S+ \(with variable substitutions/) {
+	    local($/); open(PL, "<",$name); my $txt = ~< *PL; close PL;
+	    if ($txt =~ m/Extracting \S+ \(with variable substitutions/) {
 		($pl_files{$name} = $name) =~ s/[._]pl\z//i ;
 	    }
 	    else { 
                 $pm{$name} = $self->catfile($self->{INST_LIBDIR},$name); 
             }
-	} elsif ($name =~ /\.(p[ml]|pod)\z/){
+	} elsif ($name =~ m/\.(p[ml]|pod)\z/){
 	    $pm{$name} = $self->catfile($self->{INST_LIBDIR},$name);
 	}
     }
@@ -1315,7 +1315,7 @@ sub init_MANPODS {
     # Set up names of manual pages to generate from pods
     foreach my $man (qw(MAN1 MAN3)) {
 	if ( $self->{"${man}PODS"}
-             or $self->{"INSTALL${man}DIR"} =~ /^(none|\s*)$/
+             or $self->{"INSTALL${man}DIR"} =~ m/^(none|\s*)$/
         ) {
             $self->{"${man}PODS"} ||= {};
         }
@@ -1332,9 +1332,9 @@ sub _has_pod {
 
     local *FH;
     my($ispod)=0;
-    if (open(FH,"<$file")) {
-	while (<FH>) {
-	    if (/^=(?:head\d+|item|pod)\b/) {
+    if (open(FH, "<","$file")) {
+	while ( ~< *FH) {
+	    if (m/^=(?:head\d+|item|pod)\b/) {
 		$ispod=1;
 		last;
 	    }
@@ -1383,9 +1383,9 @@ sub init_MAN3PODS {
                          # we have to convert to pod
 
     foreach my $name (keys %{$self->{PM}}) {
-	if ($name =~ /\.pod\z/ ) {
+	if ($name =~ m/\.pod\z/ ) {
 	    $manifypods{$name} = $self->{PM}{$name};
-	} elsif ($name =~ /\.p[ml]\z/ ) {
+	} elsif ($name =~ m/\.p[ml]\z/ ) {
 	    if( $self->_has_pod($name) ) {
 		$manifypods{$name} = $self->{PM}{$name};
 	    }
@@ -1398,7 +1398,7 @@ sub init_MAN3PODS {
     # To force inclusion, just name it "Configure.pod", or override 
     # MAN3PODS
     foreach my $name (keys %manifypods) {
-	if ($self->{PERL_CORE} and $name =~ /(config|setup).*\.pm/is) {
+	if ($self->{PERL_CORE} and $name =~ m/(config|setup).*\.pm/is) {
 	    delete $manifypods{$name};
 	    next;
 	}
@@ -1407,7 +1407,7 @@ sub init_MAN3PODS {
 	# everything below lib is ok
 	unless($manpagename =~ s!^\W*($parentlibs_re)\W+!!s) {
 	    $manpagename = $self->catfile(
-	        split(/::/,$self->{PARENT_NAME}),$manpagename
+	        split(m/::/,$self->{PARENT_NAME}),$manpagename
 	    );
 	}
 	$manpagename = $self->replace_manpage_separator($manpagename);
@@ -1481,7 +1481,7 @@ sub init_PM {
 
     if (@{$self->{PMLIBDIRS}}){
 	print "Searching PMLIBDIRS: @{$self->{PMLIBDIRS}}\n"
-	    if ($Verbose >= 2);
+	    if ($Verbose +>= 2);
 	require File::Find;
         File::Find::find(sub {
             if (-d $_){
@@ -1490,9 +1490,9 @@ sub init_PM {
                 }
                 return;
             }
-            return if /\#/;
-            return if /~$/;    # emacs temp files
-            return if /,v$/;   # RCS files
+            return if m/\#/;
+            return if m/~$/;    # emacs temp files
+            return if m/,v$/;   # RCS files
 
 	    my $path   = $File::Find::name;
             my $prefix = $self->{INST_LIBDIR};
@@ -1506,7 +1506,7 @@ sub init_PM {
 	    my($inst) = $self->catfile($prefix,$striplibpath);
 	    local($_) = $inst; # for backwards compatibility
 	    $inst = $self->libscan($inst);
-	    print "libscan($path) => '$inst'\n" if ($Verbose >= 2);
+	    print "libscan($path) => '$inst'\n" if ($Verbose +>= 2);
 	    return unless $inst;
 	    $self->{PM}{$path} = $inst;
 	}, @{$self->{PMLIBDIRS}});
@@ -1550,12 +1550,12 @@ sub init_main {
 ### Only UNIX:
 ###    ($self->{FULLEXT} =
 ###     $self->{NAME}) =~ s!::!/!g ; #eg. BSD/Foo/Socket
-    $self->{FULLEXT} = $self->catdir(split /::/, $self->{NAME});
+    $self->{FULLEXT} = $self->catdir(split m/::/, $self->{NAME});
 
 
     # Copied from DynaLoader:
 
-    my(@modparts) = split(/::/,$self->{NAME});
+    my(@modparts) = split(m/::/,$self->{NAME});
     my($modfname) = $modparts[-1];
 
     # Some systems have restrictions on files names for DLL's etc.
@@ -1803,7 +1803,7 @@ sub init_others {	# --- Initialize Other Attributes
     $self->{RM_RF}      ||= "rm -rf";
     $self->{TOUCH}      ||= "touch";
     $self->{TEST_F}     ||= "test -f";
-    $self->{CP}         ||= "cp";
+    $self->{CP}         ||= "ln"; # HACK to keep using original files. "cp";
     $self->{MV}         ||= "mv";
     $self->{CHMOD}      ||= "chmod";
     $self->{MKPATH}     ||= '$(ABSPERLRUN) "-MExtUtils::Command" -e mkpath';
@@ -1944,7 +1944,7 @@ sub init_PERL {
     }
 
     $self->{PERL} ||=
-        $self->find_perl(5.0, \@perls, \@defpath, $Verbose );
+        $self->find_perl('kurila', \@perls, \@defpath, $Verbose );
     # don't check if perl is executable, maybe they have decided to
     # supply switches with perl
 
@@ -2215,7 +2215,7 @@ sub installbin {
 
 	local($_) = $path; # for backwards compatibility
 	my $to = $self->libscan($path);
-	print "libscan($from) => '$to'\n" if ($Verbose >=2);
+	print "libscan($from) => '$to'\n" if ($Verbose +>=2);
 
         $to = vmsify($to) if $Is_VMS;
 	$fromto{$from} = $to;
@@ -2288,7 +2288,7 @@ sub lsdir {
     $dh->open($dir || ".") or return ();
     @ls = $dh->read;
     $dh->close;
-    @ls = grep(/$regex/, @ls) if $regex;
+    @ls = grep(m/$regex/, @ls) if $regex;
     @ls;
 }
 
@@ -2347,7 +2347,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 		MAKEAPERL=1 NORECURS=1 CCCDLFLAGS=};
 
 	foreach (@ARGV){
-		if( /\s/ ){
+		if( m/\s/ ){
 			s/=(.*)/='$1'/;
 		}
 		push @m, " \\\n\t\t$_";
@@ -2440,7 +2440,7 @@ $(MAKE_APERL_FILE) : $(FIRST_MAKEFILE) pm_to_blib
 
     $extra = [] unless $extra && ref $extra eq 'ARRAY';
     for (sort keys %static) {
-	next unless /\Q$self->{LIB_EXT}\E\z/;
+	next unless m/\Q$self->{LIB_EXT}\E\z/;
 	$_ = dirname($_) . "/extralibs.ld";
 	push @$extra, $_;
     }
@@ -2623,7 +2623,7 @@ sub needs_linking {
     my($child,$caller);
     $caller = (caller(0))[3];
     confess("needs_linking called too early") if 
-      $caller =~ /^ExtUtils::MakeMaker::/;
+      $caller =~ m/^ExtUtils::MakeMaker::/;
     return $self->{NEEDS_LINKING} if defined $self->{NEEDS_LINKING};
     if ($self->has_link_code or $self->{MAKEAPERL}){
 	$self->{NEEDS_LINKING} = 1;
@@ -2666,15 +2666,15 @@ sub parse_abstract {
     my $result;
     local *FH;
     local $/ = "\n";
-    open(FH,$parsefile) or die "Could not open '$parsefile': $!";
+    open(FH,"<",$parsefile) or die "Could not open '$parsefile': $!";
     my $inpod = 0;
     my $package = $self->{DISTNAME};
     $package =~ s/-/::/g;
-    while (<FH>) {
-        $inpod = /^=(?!cut)/ ? 1 : /^=cut/ ? 0 : $inpod;
+    while ( ~< *FH) {
+        $inpod = m/^=(?!cut)/ ? 1 : m/^=cut/ ? 0 : $inpod;
         next if !$inpod;
         chop;
-        next unless /^($package\s-\s)(.*)/;
+        next unless m/^($package\s-\s)(.*)/;
         $result = $2;
         last;
     }
@@ -2703,25 +2703,25 @@ sub parse_version {
     local *FH;
     local $/ = "\n";
     local $_;
-    open(FH,$parsefile) or die "Could not open '$parsefile': $!";
+    open(FH,"<", $parsefile) or die "Could not open '$parsefile': $!";
     my $inpod = 0;
-    while (<FH>) {
-	$inpod = /^=(?!cut)/ ? 1 : /^=cut/ ? 0 : $inpod;
-	next if $inpod || /^\s*#/;
+    while ( ~< *FH) {
+	$inpod = m/^=(?!cut)/ ? 1 : m/^=cut/ ? 0 : $inpod;
+	next if $inpod || m/^\s*#/;
 	chop;
-	next unless /(?<!\\)([\$*])(([\w\:\']*)\bVERSION)\b.*\=/;
+	next unless m/(?<!\\)([\$*])(([\w\:\']*)\bVERSION)\b.*\=/;
 	my $eval = qq{
 	    package ExtUtils::MakeMaker::_version;
 	    no strict;
-	    BEGIN { eval {
+	    BEGIN \{ eval \{
 	        require version;
 	        "version"->import;
-	    } }
+	    \} \}
 
 	    local $1$2;
-	    \$$2=undef; do {
+	    \$$2=undef; do \{
 		$_
-	    }; \$$2
+	    \}; \$$2
 	};
         local $^W = 0;
 	$result = eval($eval);
@@ -2905,7 +2905,7 @@ pm_to_blib : $(TO_INST_PM)
 };
 
     my $pm_to_blib = $self->oneliner(<<CODE, ['-MExtUtils::Install']);
-pm_to_blib({\@ARGV}, '$autodir', '\$(PM_FILTER)')
+pm_to_blib(\{\@ARGV\}, '$autodir', '\$(PM_FILTER)')
 CODE
 
     my @cmds = $self->split_command($pm_to_blib, %{$self->{PM}});
@@ -2959,7 +2959,7 @@ for a binary distribution.
 sub ppd {
     my($self) = @_;
 
-    my ($pack_ver) = join ",", (split (/\./, $self->{VERSION}), (0)x4)[0..3];
+    my ($pack_ver) = join ",", (split (m/\./, $self->{VERSION}), (0)x4)[0..3];
 
     my $abstract = $self->{ABSTRACT} || '';
     $abstract =~ s/\n/\\n/sg;
@@ -2981,7 +2981,7 @@ PPD_HTML
     foreach my $prereq (sort keys %{$self->{PREREQ_PM}}) {
         my $pre_req = $prereq;
         $pre_req =~ s/::/-/g;
-        my ($dep_ver) = join ",", (split (/\./, $self->{PREREQ_PM}{$prereq}), 
+        my ($dep_ver) = join ",", (split (m/\./, $self->{PREREQ_PM}{$prereq}), 
                                   (0) x 4) [0 .. 3];
         $ppd_xml .= sprintf <<'PPD_OUT', $pre_req, $dep_ver;
         <DEPENDENCY NAME="%s" VERSION="%s" />
@@ -2990,12 +2990,10 @@ PPD_OUT
     }
 
     my $archname = $Config{archname};
-    if ($] >= 5.008) {
         # archname did not change from 5.6 to 5.8, but those versions may
         # not be not binary compatible so now we append the part of the
         # version that changes when binary compatibility may change
         $archname .= "-". substr($Config{version},0,3);
-    }
     $ppd_xml .= sprintf <<'PPD_OUT', $archname;
         <OS NAME="$(OSNAME)" />
         <ARCHITECTURE NAME="%s" />
@@ -3065,20 +3063,20 @@ sub prefixify {
 
     $rprefix .= '/' if $sprefix =~ m|/$|;
 
-    print STDERR "  prefixify $var => $path\n" if $Verbose >= 2;
-    print STDERR "    from $sprefix to $rprefix\n" if $Verbose >= 2;
+    print STDERR "  prefixify $var => $path\n" if $Verbose +>= 2;
+    print STDERR "    from $sprefix to $rprefix\n" if $Verbose +>= 2;
 
     if( $self->{ARGS}{PREFIX} && $self->file_name_is_absolute($path) && 
         $path !~ s{^\Q$sprefix\E\b}{$rprefix}s ) 
     {
 
-        print STDERR "    cannot prefix, using default.\n" if $Verbose >= 2;
-        print STDERR "    no default!\n" if !$default && $Verbose >= 2;
+        print STDERR "    cannot prefix, using default.\n" if $Verbose +>= 2;
+        print STDERR "    no default!\n" if !$default && $Verbose +>= 2;
 
         $path = $self->catdir($rprefix, $default) if $default;
     }
 
-    print "    now $path\n" if $Verbose >= 2;
+    print "    now $path\n" if $Verbose +>= 2;
     return $self->{uc $var} = $path;
 }
 
@@ -3197,7 +3195,7 @@ sub oneliner {
     $cmd =~ s{^\n+}{};
     $cmd =~ s{\n+$}{};
 
-    my @cmds = split /\n/, $cmd;
+    my @cmds = split m/\n/, $cmd;
     $cmd = join " \n\t  -e ", map $self->quote_literal($_), @cmds;
     $cmd = $self->escape_newlines($cmd);
 
@@ -3590,7 +3588,7 @@ sub tool_xsubpp {
     if ($Is_VMS                          &&
         $Config{'ldflags'}               && 
         $Config{'ldflags'} =~ m!/Debug!i &&
-        (!exists($self->{XSOPT}) || $self->{XSOPT} !~ /linenumbers/)
+        (!exists($self->{XSOPT}) || $self->{XSOPT} !~ m/linenumbers/)
        ) 
     {
         unshift(@tmargs,'-nolinenumbers');
