@@ -62,9 +62,9 @@ sub wraplist {
       # Perl bug -- seems to occasionally insert extra elements when
       # traversing array (scalar(@array) doesn't show them, but
       # foreach(@array) does) (5.00307)
-      next unless $word =~ /\w/;
+      next unless $word =~ m/\w/;
       $line .= ' ' if length($line);
-      if ($hlen > 80) { $line .= "\\\n\t"; $hlen = 0; }
+      if ($hlen +> 80) { $line .= "\\\n\t"; $hlen = 0; }
       $line .= $word;
       $hlen += length($word) + 2;
     }
@@ -130,8 +130,8 @@ sub guess_name {
       }
     }
     if (open(PM,"${defpm}.pm")){
-        while (<PM>) {
-            if (/^\s*package\s+([^;]+)/i) {
+        while ( ~< *PM) {
+            if (m/^\s*package\s+([^;]+)/i) {
                 $defname = $1;
                 last;
             }
@@ -176,13 +176,13 @@ sub find_perl {
         # executable that's less likely to be from an old installation.
         @snames = sort { my($ba) = $a =~ m!([^:>\]/]+)$!;  # basename
                          my($bb) = $b =~ m!([^:>\]/]+)$!;
-                         my($ahasdir) = (length($a) - length($ba) > 0);
-                         my($bhasdir) = (length($b) - length($bb) > 0);
+                         my($ahasdir) = (length($a) - length($ba) +> 0);
+                         my($bhasdir) = (length($b) - length($bb) +> 0);
                          if    ($ahasdir and not $bhasdir) { return 1; }
                          elsif ($bhasdir and not $ahasdir) { return -1; }
-                         else { $bb =~ /\d/ <=> $ba =~ /\d/
+                         else { $bb =~ m/\d/ <+> $ba =~ m/\d/
                                   or substr($ba,0,1) cmp substr($bb,0,1)
-                                  or length($bb) <=> length($ba) } } @$names;
+                                  or length($bb) <+> length($ba) } } @$names;
     }
     else {
         @sdirs  = @$dirs;
@@ -191,7 +191,7 @@ sub find_perl {
 
     # Image names containing Perl version use '_' instead of '.' under VMS
     foreach $name (@snames) { $name =~ s/\.(\d+)$/_$1/; }
-    if ($trace >= 2){
+    if ($trace +>= 2){
 	print "Looking for perl $ver by these names:\n";
 	print "\t@snames,\n";
 	print "in these dirs:\n";
@@ -204,7 +204,7 @@ sub find_perl {
 	    # We've covered relative dirs; everything else is an absolute
 	    # dir (probably an installed location).  First, we'll try potential
 	    # command names, to see whether we can avoid a long MCR expression.
-	    foreach $name (@snames) { push(@cand,$name) if $name =~ /^[\w\-\$]+$/; }
+	    foreach $name (@snames) { push(@cand,$name) if $name =~ m/^[\w\-\$]+$/; }
 	    $inabs++; # Should happen above in next $dir, but just in case . . .
 	}
 	foreach $name (@snames){
@@ -213,30 +213,30 @@ sub find_perl {
 	}
     }
     foreach $name (@cand) {
-	print "Checking $name\n" if ($trace >= 2);
+	print "Checking $name\n" if ($trace +>= 2);
 	# If it looks like a potential command, try it without the MCR
-        if ($name =~ /^[\w\-\$]+$/) {
-            open(TCF,">temp_mmvms.com") || die('unable to open temp file');
+        if ($name =~ m/^[\w\-\$]+$/) {
+            open(TCF, ">","temp_mmvms.com") || die('unable to open temp file');
             print TCF "\$ set message/nofacil/nosever/noident/notext\n";
             print TCF "\$ $name -e \"require $ver; print \"\"VER_OK\\n\"\"\"\n";
             close TCF;
             $rslt = `\@temp_mmvms.com` ;
             unlink('temp_mmvms.com');
-            if ($rslt =~ /VER_OK/) {
+            if ($rslt =~ m/VER_OK/) {
                 print "Using PERL=$name\n" if $trace;
                 return $name;
             }
         }
 	next unless $vmsfile = $self->maybe_command($name);
 	$vmsfile =~ s/;[\d\-]*$//;  # Clip off version number; we can use a newer version as well
-	print "Executing $vmsfile\n" if ($trace >= 2);
-        open(TCF,">temp_mmvms.com") || die('unable to open temp file');
+	print "Executing $vmsfile\n" if ($trace +>= 2);
+        open(TCF, ">","temp_mmvms.com") || die('unable to open temp file');
         print TCF "\$ set message/nofacil/nosever/noident/notext\n";
         print TCF "\$ mcr $vmsfile -e \"require $ver; print \"\"VER_OK\\n\"\"\" \n";
         close TCF;
         $rslt = `\@temp_mmvms.com`;
         unlink('temp_mmvms.com');
-        if ($rslt =~ /VER_OK/) {
+        if ($rslt =~ m/VER_OK/) {
 	    print "Using PERL=MCR $vmsfile\n" if $trace;
 	    return "MCR $vmsfile";
 	}
@@ -400,7 +400,7 @@ sub init_main {
 
     $self->{DEFINE} ||= '';
     if ($self->{DEFINE} ne '') {
-        my(@terms) = split(/\s+/,$self->{DEFINE});
+        my(@terms) = split(m/\s+/,$self->{DEFINE});
         my(@defs,@udefs);
         foreach my $def (@terms) {
             next unless $def;
@@ -410,7 +410,7 @@ sub init_main {
                 $def =~ s/='(.*)'$/=$1/;  # then remove shell-protection ''
                 $def =~ s/^'(.*)'$/$1/;   # from entire term or argument
             }
-            if ($def =~ /=/) {
+            if ($def =~ m/=/) {
                 $def =~ s/"/""/g;  # Protect existing " from DCL
                 $def = qq["$def"]; # and quote to prevent parsing of =
             }
@@ -495,15 +495,15 @@ CODE
     # it work.  However, Unix's DEV_NULL is quite wrong for VMS.
     $self->{DEV_NULL}   = '';
 
-    if ($self->{OBJECT} =~ /\s/) {
+    if ($self->{OBJECT} =~ m/\s/) {
         $self->{OBJECT} =~ s/(\\)?\n+\s+/ /g;
         $self->{OBJECT} = $self->wraplist(
-            map $self->fixpath($_,0), split /,?\s+/, $self->{OBJECT}
+            map $self->fixpath($_,0), split m/,?\s+/, $self->{OBJECT}
         );
     }
 
     $self->{LDFROM} = $self->wraplist(
-        map $self->fixpath($_,0), split /,?\s+/, $self->{LDFROM}
+        map $self->fixpath($_,0), split m/,?\s+/, $self->{LDFROM}
     );
 }
 
@@ -575,7 +575,7 @@ sub constants {
     my($self) = @_;
 
     # Be kind about case for pollution
-    for (@ARGV) { $_ = uc($_) if /POLLUTE/i; }
+    for (@ARGV) { $_ = uc($_) if m/POLLUTE/i; }
 
     # Cleanup paths for directories in MMS macros.
     foreach my $macro ( qw [
@@ -586,7 +586,7 @@ sub constants {
                       ) 
     {
         next unless defined $self->{$macro};
-        next if $macro =~ /MAN/ && $self->{$macro} eq 'none';
+        next if $macro =~ m/MAN/ && $self->{$macro} eq 'none';
         $self->{$macro} = $self->fixpath($self->{$macro},1);
     }
 
@@ -674,14 +674,14 @@ sub cflags {
          " required to modify CC command for $self->{'BASEEXT'}\n"
     if ($Config{$name});
 
-    if ($quals =~ / -[DIUOg]/) {
-	while ($quals =~ / -([Og])(\d*)\b/) {
+    if ($quals =~ m/ -[DIUOg]/) {
+	while ($quals =~ m/ -([Og])(\d*)\b/) {
 	    my($type,$lvl) = ($1,$2);
 	    $quals =~ s/ -$type$lvl\b\s*//;
 	    if ($type eq 'g') { $flagoptstr = '/NoOptimize'; }
 	    else { $flagoptstr = '/Optimize' . (defined($lvl) ? "=$lvl" : ''); }
 	}
-	while ($quals =~ / -([DIU])(\S+)/) {
+	while ($quals =~ m/ -([DIU])(\S+)/) {
 	    my($type,$def) = ($1,$2);
 	    $quals =~ s/ -$type$def\s*//;
 	    $def =~ s/"/""/g;
@@ -722,7 +722,7 @@ sub cflags {
 
     # Likewise with $self->{INC} and /Include
     if ($self->{'INC'}) {
-	my(@includes) = split(/\s+/,$self->{INC});
+	my(@includes) = split(m/\s+/,$self->{INC});
 	foreach (@includes) {
 	    s/^-I//;
 	    $incstr .= ','.$self->fixpath($_,1);
@@ -737,7 +737,7 @@ sub cflags {
     $self->{OPTIMIZE} ||= $flagoptstr || $Config{'optimize'};
     if ($self->{OPTIMIZE} !~ m!/!) {
 	if    ($self->{OPTIMIZE} =~ m!-g!) { $self->{OPTIMIZE} = '/Debug/NoOptimize' }
-	elsif ($self->{OPTIMIZE} =~ /-O(\d*)/) {
+	elsif ($self->{OPTIMIZE} =~ m/-O(\d*)/) {
 	    $self->{OPTIMIZE} = '/Optimize' . (defined($1) ? "=$1" : '');
 	}
 	else {
@@ -948,8 +948,8 @@ $(BASEEXT).opt : Makefile.PL
 	q[, 'FUNCLIST' => ],neatvalue($funclist),qq[)"\n];
 
     push @m, '	$(PERL) -e "print ""$(INST_STATIC)/Include=';
-    if ($self->{OBJECT} =~ /\bBASEEXT\b/ or
-        $self->{OBJECT} =~ /\b$self->{BASEEXT}\b/i) { 
+    if ($self->{OBJECT} =~ m/\bBASEEXT\b/ or
+        $self->{OBJECT} =~ m/\b$self->{BASEEXT}\b/i) { 
         push @m, ($Config{d_vms_case_sensitive_symbols}
 	           ? uc($self->{BASEEXT}) :'$(BASEEXT)');
     }
@@ -965,7 +965,7 @@ $(BASEEXT).opt : Makefile.PL
 	$tmp = shift @omods;
 	foreach $elt (@omods) {
 	    $tmp .= ",$elt";
-		if (length($tmp) > 80) { push @lines, $tmp;  $tmp = ''; }
+		if (length($tmp) +> 80) { push @lines, $tmp;  $tmp = ''; }
 	}
 	push @lines, $tmp;
 	push @m, '(', join( qq[, -\\n\\t"";" >>\$(MMS\$TARGET)\n\t\$(PERL) -e "print ""], @lines),')';
@@ -976,13 +976,13 @@ $(BASEEXT).opt : Makefile.PL
 	my($lib); my($line) = '';
 	foreach $lib (split ' ', $self->{LDLOADLIBS}) {
 	    $lib =~ s%\$%\\\$%g;  # Escape '$' in VMS filespecs
-	    if (length($line) + length($lib) > 160) {
-		push @m, "\t\$(PERL) -e \"print qq{$line}\" >>\$(MMS\$TARGET)\n";
+	    if (length($line) + length($lib) +> 160) {
+		push @m, "\t\$(PERL) -e \"print qq\{$line\}\" >>\$(MMS\$TARGET)\n";
 		$line = $lib . '\n';
 	    }
 	    else { $line .= $lib . '\n'; }
 	}
-	push @m, "\t\$(PERL) -e \"print qq{$line}\" >>\$(MMS\$TARGET)\n" if $line;
+	push @m, "\t\$(PERL) -e \"print qq\{$line\}\" >>\$(MMS\$TARGET)\n" if $line;
     }
 
     join('',@m);
@@ -1430,8 +1430,8 @@ $(MAP_TARGET) :: $(MAKE_APERL_FILE)
     # (e.g. Intuit::DWIM will precede Intuit, so unresolved
     # references from [.intuit.dwim]dwim.obj can be found
     # in [.intuit]intuit.olb).
-    for (sort { length($a) <=> length($b) } keys %olbs) {
-	next unless $olbs{$_} =~ /\Q$self->{LIB_EXT}\E$/;
+    for (sort { length($a) <+> length($b) } keys %olbs) {
+	next unless $olbs{$_} =~ m/\Q$self->{LIB_EXT}\E$/;
 	my($dir) = $self->fixpath($_,1);
 	my($extralibs) = $dir . "extralibs.ld";
 	my($extopt) = $dir . $olbs{$_};
@@ -1440,8 +1440,8 @@ $(MAP_TARGET) :: $(MAKE_APERL_FILE)
 	# Get external libraries this extension will need
 	if (-f $extralibs ) {
 	    my %seenthis;
-	    open LIST,$extralibs or warn $!,next;
-	    while (<LIST>) {
+	    open LIST, "<",$extralibs or warn $!,next;
+	    while ( ~< *LIST) {
 		chomp;
 		# Include a library in the link only once, unless it's mentioned
 		# multiple times within a single extension's options file, in which
@@ -1456,9 +1456,9 @@ $(MAP_TARGET) :: $(MAKE_APERL_FILE)
 	}
 	# Get full name of extension for ExtUtils::Miniperl
 	if (-f $extopt) {
-	    open OPT,$extopt or die $!;
-	    while (<OPT>) {
-		next unless /(?:UNIVERSAL|VECTOR)=boot_([\w_]+)/;
+	    open OPT, "<",$extopt or die $!;
+	    while ( ~< *OPT) {
+		next unless m/(?:UNIVERSAL|VECTOR)=boot_([\w_]+)/;
 		my $pkg = $1;
 		$pkg =~ s#__*#::#g;
 		push @staticpkgs,$pkg;
@@ -1483,7 +1483,7 @@ $(MAP_TARGET) :: $(MAKE_APERL_FILE)
     else          { $extralist = ''; }
     # Let ExtUtils::Liblist find the necessary libs for us (but skip PerlShr)
     # that's what we're building here).
-    push @optlibs, grep { !/PerlShr/i } split ' ', +($self->ext())[2];
+    push @optlibs, grep { !m/PerlShr/i } split ' ', +($self->ext())[2];
     if ($libperl) {
 	unless (-f $libperl || -f ($libperl = $self->catfile($Config{'installarchlib'},'CORE',$libperl))) {
 	    print STDOUT "Warning: $libperl not found\n";
@@ -1502,9 +1502,9 @@ $(MAP_TARGET) :: $(MAKE_APERL_FILE)
     }
     $libperldir = $self->fixpath((fileparse($libperl))[1],1);
 
-    push @m, '
-# Fill in the target you want to produce if it\'s not perl
-MAP_TARGET    = ',$self->fixpath($target,0),'
+    push @m, q|
+# Fill in the target you want to produce if it's not perl
+MAP_TARGET    = |,$self->fixpath($target,0),'
 MAP_SHRTARGET = ',$self->fixpath($shrtarget,0),"
 MAP_LINKCMD   = $linkcmd
 MAP_PERLINC   = ", $perlinc ? map('"$_" ',@{$perlinc}) : '',"
@@ -1533,7 +1533,7 @@ $(MAP_TARGET) : $(MAP_SHRTARGET) ',"${tmpdir}perlmain\$(OBJ_EXT) ${tmpdir}PerlSh
     push @m,"\n${tmpdir}perlmain.c : \$(FIRST_MAKEFILE)\n\t\$(NOECHO) \$(PERL) -e 1 >${tmpdir}Writemain.tmp\n";
     push @m, "# More from the 255-char line length limit\n";
     foreach (@staticpkgs) {
-	push @m,'	$(NOECHO) $(PERL) -e "print q{',$_,qq[}" >>${tmpdir}Writemain.tmp\n];
+	push @m,'	$(NOECHO) $(PERL) -e "print q{',$_,qq[\}" >>${tmpdir}Writemain.tmp\n];
     }
 
     push @m, sprintf <<'MAKE_FRAG', $tmpdir, $tmpdir;
@@ -1615,7 +1615,7 @@ sub prefixify {
     $sprefix = VMS::Filespec::vmspath($sprefix) if $sprefix;
 
     $default = VMS::Filespec::vmsify($default) 
-      unless $default =~ /\[.*\]/;
+      unless $default =~ m/\[.*\]/;
 
     (my $var_no_install = $var) =~ s/^install//;
     my $path = $self->{uc $var} || 
@@ -1623,23 +1623,23 @@ sub prefixify {
                $Config{lc $var} || $Config{lc $var_no_install};
 
     if( !$path ) {
-        print STDERR "  no Config found for $var.\n" if $Verbose >= 2;
+        print STDERR "  no Config found for $var.\n" if $Verbose +>= 2;
         $path = $self->_prefixify_default($rprefix, $default);
     }
     elsif( !$self->{ARGS}{PREFIX} || !$self->file_name_is_absolute($path) ) {
         # do nothing if there's no prefix or if its relative
     }
     elsif( $sprefix eq $rprefix ) {
-        print STDERR "  no new prefix.\n" if $Verbose >= 2;
+        print STDERR "  no new prefix.\n" if $Verbose +>= 2;
     }
     else {
 
-        print STDERR "  prefixify $var => $path\n"     if $Verbose >= 2;
-        print STDERR "    from $sprefix to $rprefix\n" if $Verbose >= 2;
+        print STDERR "  prefixify $var => $path\n"     if $Verbose +>= 2;
+        print STDERR "    from $sprefix to $rprefix\n" if $Verbose +>= 2;
 
         my($path_vol, $path_dirs) = $self->splitpath( $path );
         if( $path_vol eq $Config{vms_prefix}.':' ) {
-            print STDERR "  $Config{vms_prefix}: seen\n" if $Verbose >= 2;
+            print STDERR "  $Config{vms_prefix}: seen\n" if $Verbose +>= 2;
 
             $path_dirs =~ s{^\[}{\[.} unless $path_dirs =~ m{^\[\.};
             $path = $self->_catprefix($rprefix, $path_dirs);
@@ -1649,7 +1649,7 @@ sub prefixify {
         }
     }
 
-    print "    now $path\n" if $Verbose >= 2;
+    print "    now $path\n" if $Verbose +>= 2;
     return $self->{uc $var} = $path;
 }
 
@@ -1657,14 +1657,14 @@ sub prefixify {
 sub _prefixify_default {
     my($self, $rprefix, $default) = @_;
 
-    print STDERR "  cannot prefix, using default.\n" if $Verbose >= 2;
+    print STDERR "  cannot prefix, using default.\n" if $Verbose +>= 2;
 
     if( !$default ) {
-        print STDERR "No default!\n" if $Verbose >= 1;
+        print STDERR "No default!\n" if $Verbose +>= 1;
         return;
     }
     if( !$rprefix ) {
-        print STDERR "No replacement prefix!\n" if $Verbose >= 1;
+        print STDERR "No replacement prefix!\n" if $Verbose +>= 1;
         return '';
     }
 
@@ -1750,7 +1750,7 @@ sub echo {
 
     my @cmds = ("\$(NOECHO) $opencmd MMECHOFILE $file ");
     push @cmds, map { '$(NOECHO) Write MMECHOFILE '.$self->quote_literal($_) } 
-                split /\n/, $text;
+                split m/\n/, $text;
     push @cmds, '$(NOECHO) Close MMECHOFILE';
     return @cmds;
 }
@@ -1830,8 +1830,8 @@ sub eliminate_macros {
     return '' unless $path;
     $self = {} unless ref $self;
 
-    if ($path =~ /\s/) {
-      return join ' ', map { $self->eliminate_macros($_) } split /\s+/, $path;
+    if ($path =~ m/\s/) {
+      return join ' ', map { $self->eliminate_macros($_) } split m/\s+/, $path;
     }
 
     my($npath) = unixify($path);
@@ -1892,14 +1892,14 @@ sub fixpath {
     $self = bless {} unless ref $self;
     my($fixedpath,$prefix,$name);
 
-    if ($path =~ /[ \t]/) {
+    if ($path =~ m/[ \t]/) {
       return join ' ',
              map { $self->fixpath($_,$force_path) }
-	     split /[ \t]+/, $path;
+	     split m/[ \t]+/, $path;
     }
 
     if ($path =~ m#^\$\([^\)]+\)\Z(?!\n)#s || $path =~ m#[/:>\]]#) { 
-        if ($force_path or $path =~ /(?:DIR\)|\])\Z(?!\n)/) {
+        if ($force_path or $path =~ m/(?:DIR\)|\])\Z(?!\n)/) {
             $fixedpath = vmspath($self->eliminate_macros($path));
         }
         else {
@@ -1909,7 +1909,7 @@ sub fixpath {
     elsif ((($prefix,$name) = ($path =~ m#^\$\(([^\)]+)\)(.+)#s)) && $self->{$prefix}) {
         my($vmspre) = $self->eliminate_macros("\$($prefix)");
         # is it a dir or just a name?
-        $vmspre = ($vmspre =~ m|/| or $prefix =~ /DIR\Z(?!\n)/) ? vmspath($vmspre) : '';
+        $vmspre = ($vmspre =~ m|/| or $prefix =~ m/DIR\Z(?!\n)/) ? vmspath($vmspre) : '';
         $fixedpath = ($vmspre ? $vmspre : $self->{$prefix}) . $name;
         $fixedpath = vmspath($fixedpath) if $force_path;
     }
@@ -1918,7 +1918,7 @@ sub fixpath {
         $fixedpath = vmspath($fixedpath) if $force_path;
     }
     # No hints, so we try to guess
-    if (!defined($force_path) and $fixedpath !~ /[:>(.\]]/) {
+    if (!defined($force_path) and $fixedpath !~ m/[:>(.\]]/) {
         $fixedpath = vmspath($fixedpath) if -d $fixedpath;
     }
 
@@ -1928,7 +1928,7 @@ sub fixpath {
     # prepended during trip through Unix syntax in eliminate_macros(), since
     # Unix syntax has no way to express "absolute from the top of this device's
     # directory tree".
-    if ($path =~ /^[\[>][^.\-]/) { $fixedpath =~ s/^[^\[<]+//; }
+    if ($path =~ m/^[\[>][^.\-]/) { $fixedpath =~ s/^[^\[<]+//; }
 
     return $fixedpath;
 }
