@@ -5,11 +5,12 @@ use Config;
 use File::Basename;
 use File::Spec;
 use Symbol;
+use strict;
 
 require Exporter;
 
-@ISA = qw(Exporter);
-@EXPORT_OK = qw(process_file);
+our @ISA = qw(Exporter);
+our @EXPORT_OK = qw(process_file);
 
 # use strict;  # One of these days...
 
@@ -17,7 +18,7 @@ my(@XSStack);	# Stack of conditionals and INCLUDEs
 my($XSS_work_idx, $cpp_next_tmp);
 
 use vars qw($VERSION);
-$VERSION = '2.18';
+$VERSION = '2.18_02';
 
 use vars qw(%input_expr %output_expr $ProtoUsed @InitFileCode $FH $proto_re $Overload $errors $Fallback
 	    $cplusplus $hiertype $WantPrototypes $WantVersionChk $except $WantLineNumbers
@@ -32,6 +33,37 @@ use vars qw(%input_expr %output_expr $ProtoUsed @InitFileCode $FH $proto_re $Ove
             @line_no $ret_type $func_header $orig_args
 	   ); # Add these just to get compilation to happen.
 
+our ($func_args, $PPCODE, $CODE, $EXPLICIT_RETURN, $ALIAS, $INTERFACE, $Full_func_name,
+     $cond, $min_args, $pname, $condnum, $thisdone, $retvaldone, $deferred, $gotRETVAL,
+     $RETVAL_code, %outargs, $DoSetMagic, %XsubAliases, $name, $value, @Attributes,
+     $XsubAliases, %Interfaces, $Packid, $proto, $Module_cname, $Interfaces,
+     $name_printed, $var_num, $orig_alias, $Packprefix, %XsubAliasValues, $Module,
+     $type, $num, $var, $init, $arg, $argoff, $ntype, $tk, $subtype,
+     $func_name, $expr, $do_setmagic, $do_push, $subexpr);
+
+# Constants:
+
+our $END = "!End!\n\n";		# "impossible" keyword (multiple newline)
+our $Is_VMS = $^O eq 'VMS';
+
+# constant regex.
+our ($C_group_rex, $C_arg);
+# Group in C (no support for comments or literals)
+$C_group_rex = qr/ [({\[]
+		       (?: (?> [^()\[\]{}]+ ) | (??{ $C_group_rex }) )*
+		       [)}\]] /x ;
+# Chunk in C without comma at toplevel (no comments):
+$C_arg = qr/ (?: (?> [^()\[\]{},"']+ )
+	     |   (??{ $C_group_rex })
+	     |   " (?: (?> [^\\"]+ )
+		   |   \\.
+		   )* "		# String literal
+			    |   ' (?: (?> [^\\']+ ) | \\. )* ' # Char literal
+	     )* /xs;
+
+
+
+our $SymSet;
 
 sub process_file {
   
@@ -60,9 +92,7 @@ sub process_file {
 
   # Global Constants
   
-  my ($Is_VMS, $SymSet);
-  if ($^O eq 'VMS') {
-    $Is_VMS = 1;
+  if ($Is_VMS) {
     # Establish set of global symbols with max length 28, since xsubpp
     # will later add the 'XS_' prefix.
     require ExtUtils::XSSymSet;
@@ -101,12 +131,12 @@ sub process_file {
   }
   
   # Open the input file
-  open($FH, $args{filename}) or die "cannot open $args{filename}: $!\n";
+  open($FH, "<", $args{filename}) or die "cannot open $args{filename}: $!\n";
 
   # Open the output file if given as a string.  If they provide some
   # other kind of reference, trust them that we can print to it.
   if (not ref $args{output}) {
-    open my($fh), "> $args{output}" or die "Can't create $args{output}: $!";
+    open my($fh), ">", "$args{output}" or die "Can't create $args{output}: $!";
     $args{outfile} = $args{output};
     $args{output} = $fh;
   }
@@ -145,21 +175,21 @@ sub process_file {
     # skip directories, binary files etc.
     warn("Warning: ignoring non-text typemap file '$typemap'\n"), next
       unless -T $typemap ;
-    open(TYPEMAP, $typemap)
+    open(TYPEMAP, "<", $typemap)
       or warn ("Warning: could not open typemap file '$typemap': $!\n"), next;
     my $mode = 'Typemap';
     my $junk = "" ;
     my $current = \$junk;
-    while (<TYPEMAP>) {
-      next if /^\s*		#/;
+    while ( ~< *TYPEMAP) {
+      next if m/^\s*		#/;
         my $line_no = $. + 1;
-      if (/^INPUT\s*$/) {
+      if (m/^INPUT\s*$/) {
 	$mode = 'Input';   $current = \$junk;  next;
       }
-      if (/^OUTPUT\s*$/) {
+      if (m/^OUTPUT\s*$/) {
 	$mode = 'Output';  $current = \$junk;  next;
       }
-      if (/^TYPEMAP\s*$/) {
+      if (m/^TYPEMAP\s*$/) {
 	$mode = 'Typemap'; $current = \$junk;  next;
       }
       if ($mode eq 'Typemap') {
@@ -167,8 +197,8 @@ sub process_file {
 	my $line = $_ ;
 	TrimWhitespace($_) ;
 	# skip blank lines and comment lines
-	next if /^$/ or /^#/ ;
-	my($type,$kind, $proto) = /^\s*(.*?\S)\s+(\S+)\s*($proto_re*)\s*$/ or
+	next if m/^$/ or m/^#/ ;
+	my($type,$kind, $proto) = m/^\s*(.*?\S)\s+(\S+)\s*($proto_re*)\s*$/ or
 	  warn("Warning: File '$typemap' Line $. '$line' TYPEMAP entry needs 2 or 3 columns\n"), next;
 	$type = TidyType($type) ;
 	$type_kind{$type} = $kind ;
@@ -177,7 +207,7 @@ sub process_file {
 	warn("Warning: File '$typemap' Line $. '$line' Invalid prototype '$proto'\n")
 	  unless ValidProtoString($proto) ;
 	$proto_letter{$type} = C_string($proto) ;
-      } elsif (/^\s/) {
+      } elsif (m/^\s/) {
 	$$current .= $_;
       } elsif ($mode eq 'Input') {
 	s/\s+$//;
@@ -192,12 +222,20 @@ sub process_file {
     close(TYPEMAP);
   }
 
-  foreach my $key (keys %input_expr) {
-    $input_expr{$key} =~ s/;*\s+\z//;
+  foreach my $value (values %input_expr) {
+    $value =~ s/;*\s+\z//;
+    # Move C pre-processor instructions to column 1 to be strictly ANSI
+    # conformant. Some pre-processors are fussy about this.
+    $value =~ s/^\s+#/#/mg;
+  }
+  foreach my $value (values %output_expr) {
+    # And again.
+    $value =~ s/^\s+#/#/mg;
   }
 
   my ($cast, $size);
-  our $bal = qr[(?:(?>[^()]+)|\((??{ $bal })\))*]; # ()-balanced
+  our $bal;
+  $bal = qr[(?:(?>[^()]+)|\((??{ $bal })\))*]; # ()-balanced
   $cast = qr[(?:\(\s*SV\s*\*\s*\)\s*)?]; # Optional (SV*) cast
   $size = qr[,\s* (??{ $bal }) ]x; # Third arg (to setpvn)
 
@@ -215,8 +253,6 @@ sub process_file {
     $targetable{$key} = [$t, $with_size, $arg, $sarg] if $t;
   }
 
-  my $END = "!End!\n\n";		# "impossible" keyword (multiple newline)
-
   # Match an XS keyword
   $BLOCK_re= '\s*(' . join('|', qw(
 				   REQUIRE BOOT CASE PREINIT INPUT INIT CODE PPCODE OUTPUT
@@ -225,20 +261,6 @@ sub process_file {
 				  )) . "|$END)\\s*:";
 
   
-  our ($C_group_rex, $C_arg);
-  # Group in C (no support for comments or literals)
-  $C_group_rex = qr/ [({\[]
-		       (?: (?> [^()\[\]{}]+ ) | (??{ $C_group_rex }) )*
-		       [)}\]] /x ;
-  # Chunk in C without comma at toplevel (no comments):
-  $C_arg = qr/ (?: (?> [^()\[\]{},"']+ )
-	     |   (??{ $C_group_rex })
-	     |   " (?: (?> [^\\"]+ )
-		   |   \\.
-		   )* "		# String literal
-			    |   ' (?: (?> [^\\']+ ) | \\. )* ' # Char literal
-	     )* /xs;
-  
   # Identify the version of xsubpp used
   print <<EOM ;
 /*
@@ -256,11 +278,12 @@ EOM
     if $WantLineNumbers;
 
   firstmodule:
-  while (<$FH>) {
-    if (/^=/) {
+  local $_;
+  while ( ~< $FH) {
+    if (m/^=/) {
       my $podstartline = $.;
       do {
-	if (/^=cut\s*$/) {
+	if (m/^=cut\s*$/) {
 	  # We can't just write out a /* */ comment, as our embedded
 	  # POD might itself be in a comment. We can't put a /**/
 	  # comment inside #if 0, as the C standard says that the source
@@ -280,7 +303,7 @@ EOM
 	  next firstmodule
 	}
 	
-      } while (<$FH>);
+      } while ( ~< $FH);
       # At this point $. is at end of file so die won't state the start
       # of the problem, and as we haven't yet read any lines &death won't
       # show the correct line in the message either.
@@ -288,7 +311,7 @@ EOM
 	unless $lastline;
     }
     last if ($Package, $Prefix) =
-      /^MODULE\s*=\s*[\w:]+(?:\s+PACKAGE\s*=\s*([\w:]+))?(?:\s+PREFIX\s*=\s*(\S+))?\s*$/;
+      m/^MODULE\s*=\s*[\w:]+(?:\s+PACKAGE\s*=\s*([\w:]+))?(?:\s+PREFIX\s*=\s*(\S+))?\s*$/;
     
     print $_;
   }
@@ -311,11 +334,129 @@ EOF
 
  PARAGRAPH:
   while (fetch_para()) {
+      process_para(%args);
+  }
+
+  if ($Overload) # make it findable with fetchmethod
+  {
+    print Q(<<"EOF");
+#XS(XS_${Packid}_nil); /* prototype to pass -Wmissing-prototypes */
+#XS(XS_${Packid}_nil)
+#\{
+#   XSRETURN_EMPTY;
+#\}
+#
+EOF
+    unshift(@InitFileCode, <<"MAKE_FETCHMETHOD_WORK");
+    /* Making a sub named "${Package}::()" allows the package */
+    /* to be findable via fetchmethod(), and causes */
+    /* overload::Overloaded("${Package}") to return true. */
+    newXS("${Package}::()", XS_${Packid}_nil, file$proto);
+MAKE_FETCHMETHOD_WORK
+  }
+
+  # print initialization routine
+
+  print Q(<<"EOF");
+##ifdef __cplusplus
+#extern "C"
+##endif
+EOF
+
+  print Q(<<"EOF");
+#XS(boot_$Module_cname); /* prototype to pass -Wmissing-prototypes */
+#XS(boot_$Module_cname)
+EOF
+
+  print Q(<<"EOF");
+#[[
+##ifdef dVAR
+#    dVAR; dXSARGS;
+##else
+#    dXSARGS;
+##endif
+EOF
+
+  #-Wall: if there is no $Full_func_name there are no xsubs in this .xs
+  #so `file' is unused
+  print Q(<<"EOF") if $Full_func_name;
+#    char* file = __FILE__;
+EOF
+
+  print Q("#\n");
+
+  print Q(<<"EOF");
+#    PERL_UNUSED_VAR(cv); /* -W */
+#    PERL_UNUSED_VAR(items); /* -W */
+EOF
+    
+  print Q(<<"EOF") if $WantVersionChk ;
+#    XS_VERSION_BOOTCHECK ;
+#
+EOF
+
+  print Q(<<"EOF") if defined $XsubAliases or defined $Interfaces ;
+#    \{
+#        CV * cv ;
+#
+EOF
+
+  print Q(<<"EOF") if ($Overload);
+#    /* register the overloading (type 'A') magic */
+#    PL_amagic_generation++;
+#    /* The magic for overload gets a GV* via gv_fetchmeth as */
+#    /* mentioned above, and looks in the SV* slot of it for */
+#    /* the "fallback" status. */
+#    sv_setsv(
+#        get_sv( "${Package}::()", TRUE ),
+#        $Fallback
+#    );
+EOF
+
+  print @InitFileCode;
+
+  print Q(<<"EOF") if defined $XsubAliases or defined $Interfaces ;
+#    \}
+EOF
+
+  if (@BootCode)
+  {
+    print "\n    /* Initialisation Section */\n\n" ;
+    @line = @BootCode;
+    print_section();
+    print "\n    /* End of Initialisation Section */\n\n" ;
+  }
+
+    print <<'EOF';
+    if (PL_unitcheckav)
+         call_list(PL_scopestack_ix, PL_unitcheckav);
+EOF
+
+  print Q(<<"EOF");
+#    XSRETURN_YES;
+#]]
+#
+EOF
+
+  warn("Please specify prototyping behavior for $filename (see perlxs manual)\n")
+    unless $ProtoUsed ;
+
+  chdir($orig_cwd);
+  select($orig_fh);
+  untie *PSEUDO_STDOUT if tied *PSEUDO_STDOUT;
+  close $FH;
+
+  return 1;
+}
+
+sub process_para {
+    my %args = @_;
+
     # Print initial preprocessor statements and blank lines
-    while (@line && $line[0] !~ /^[^\#]/) {
+    while (@line && $line[0] !~ m/^[^\#]/) {
       my $line = shift(@line);
       print $line, "\n";
-      next unless $line =~ /^\#\s*((if)(?:n?def)?|elsif|else|endif)\b/;
+      next unless $line =~ m/^\#\s*((if)(?:n?def)?|elsif|else|endif)\b/;
       my $statement = $+;
       if ($statement eq 'if') {
 	$XSS_work_idx = @XSStack;
@@ -344,7 +485,7 @@ EOF
       }
     }
     
-    next PARAGRAPH unless @line;
+    return unless @line;
     
     if ($XSS_work_idx && !$XSStack[$XSS_work_idx]{varname}) {
       # We are inside an #if, but have not yet #defined its xsubpp variable.
@@ -357,7 +498,7 @@ EOF
     death ("Code is not inside a function"
 	   ." (maybe last function was ended by a blank line "
 	   ." followed by a statement on column one?)")
-      if $line[0] =~ /^\s/;
+      if $line[0] =~ m/^\s/;
     
     my ($class, $externC, $static, $ellipsis, $wantRETVAL, $RETVAL_no_return);
     my (@fake_INPUT_pre);	# For length(s) generated variables
@@ -395,7 +536,7 @@ EOF
     if (check_keyword("BOOT")) {
       &check_cpp;
       push (@BootCode, "#line $line_no[@line_no - @line] \"$filepathname\"")
-	if $WantLineNumbers && $line[0] !~ /^\s*#\s*line\b/;
+	if $WantLineNumbers && $line[0] !~ m/^\s*#\s*line\b/;
       push (@BootCode, @line, "") ;
       next PARAGRAPH ;
     }
@@ -419,12 +560,12 @@ EOF
 
     $func_header = shift(@line);
     blurt ("Error: Cannot parse function definition from '$func_header'"), next PARAGRAPH
-      unless $func_header =~ /^(?:([\w:]*)::)?(\w+)\s*\(\s*(.*?)\s*\)\s*(const)?\s*(;\s*)?$/s;
+      unless $func_header =~ m/^(?:([\w:]*)::)?(\w+)\s*\(\s*(.*?)\s*\)\s*(const)?\s*(;\s*)?$/s;
 
     ($class, $func_name, $orig_args) =  ($1, $2, $3) ;
     $class = "$4 $class" if $4;
     ($pname = $func_name) =~ s/^($Prefix)?/$Packprefix/;
-    ($clean_func_name = $func_name) =~ s/^$Prefix//;
+    (my $clean_func_name = $func_name) =~ s/^$Prefix//;
     $Full_func_name = "${Packid}_$clean_func_name";
     if ($Is_VMS) {
       $Full_func_name = $SymSet->addsym($Full_func_name);
@@ -444,15 +585,15 @@ EOF
     my @args;
 
     my %only_C_inlist;		# Not in the signature of Perl function
-    if ($process_argtypes and $orig_args =~ /\S/) {
+    if ($process_argtypes and $orig_args =~ m/\S/) {
       my $args = "$orig_args ,";
-      if ($args =~ /^( (??{ $C_arg }) , )* $ /x) {
-	@args = ($args =~ /\G ( (??{ $C_arg }) ) , /xg);
+      if ($args =~ m/^( (??{ $C_arg }) , )* $ /x) {
+	@args = ($args =~ m/\G ( (??{ $C_arg }) ) , /xg);
 	for ( @args ) {
 	  s/^\s+//;
 	  s/\s+$//;
-	  my ($arg, $default) = / ( [^=]* ) ( (?: = .* )? ) /x;
-	  my ($pre, $name) = ($arg =~ /(.*?) \s*
+	  my ($arg, $default) = m/ ( [^=]* ) ( (?: = .* )? ) /x;
+	  my ($pre, $name) = ($arg =~ m/(.*?) \s*
 					     \b ( \w+ | length\( \s*\w+\s* \) )
 					     \s* $ /x);
 	  next unless defined($pre) && length($pre);
@@ -465,7 +606,7 @@ EOF
 	    $pre =~ s/^(IN|IN_OUTLIST|OUTLIST|OUT|IN_OUT)\s+//;
 	  }
 	  my $islength;
-	  if ($name =~ /^length\( \s* (\w+) \s* \)\z/x) {
+	  if ($name =~ m/^length\( \s* (\w+) \s* \)\z/x) {
 	    $name = "XSauto_length_of_$1";
 	    $islength = 1;
 	    die "Default value on length() argument: `$_'"
@@ -482,35 +623,36 @@ EOF
 	    $_ = "$name$default"; # Assigns to @args
 	  }
 	  $only_C_inlist{$_} = 1 if $out_type eq "OUTLIST" or $islength;
-	  push @outlist, $name if $out_type =~ /OUTLIST$/;
+	  push @outlist, $name if $out_type =~ m/OUTLIST$/;
 	  $in_out{$name} = $out_type if $out_type;
 	}
       } else {
-	@args = split(/\s*,\s*/, $orig_args);
+	@args = split(m/\s*,\s*/, $orig_args);
 	Warn("Warning: cannot parse argument list '$orig_args', fallback to split");
       }
     } else {
-      @args = split(/\s*,\s*/, $orig_args);
+      @args = split(m/\s*,\s*/, $orig_args);
       for (@args) {
 	if ($process_inout and s/^(IN|IN_OUTLIST|OUTLIST|IN_OUT|OUT)\s+//) {
 	  my $out_type = $1;
 	  next if $out_type eq 'IN';
 	  $only_C_inlist{$_} = 1 if $out_type eq "OUTLIST";
-	  push @outlist, $name if $out_type =~ /OUTLIST$/;
+          my $name = ''; # FIXME $name is wronly scoped.
+	  push @outlist, $name if $out_type =~ m/OUTLIST$/;
 	  $in_out{$_} = $out_type;
 	}
       }
     }
+    my $extra_args = 0;
+    my @args_num = ();
+    my $num_args = 0;
+    my $report_args = '';
     if (defined($class)) {
       my $arg0 = ((defined($static) or $func_name eq 'new')
 		  ? "CLASS" : "THIS");
       unshift(@args, $arg0);
       ($report_args = "$arg0, $report_args") =~ s/^\w+, $/$arg0/;
     }
-    my $extra_args = 0;
-    @args_num = ();
-    $num_args = 0;
-    my $report_args = '';
     foreach my $i (0 .. $#args) {
       if ($args[$i] =~ s/\.\.\.//) {
 	$ellipsis = 1;
@@ -526,7 +668,7 @@ EOF
 	push @args_num, ++$num_args;
 	$report_args .= ", $args[$i]";
       }
-      if ($args[$i] =~ /^([^=]*[^\s=])\s*=\s*(.*)/s) {
+      if ($args[$i] =~ m/^([^=]*[^\s=])\s*=\s*(.*)/s) {
 	$extra_args++;
 	$args[$i] = $1;
 	$defaults{$args[$i]} = $2;
@@ -534,7 +676,7 @@ EOF
       }
       $proto_arg[$i+1] = '$' ;
     }
-    $min_args = $num_args - $extra_args;
+    my $min_args = $num_args - $extra_args;
     $report_args =~ s/"/\\"/g;
     $report_args =~ s/^,\s+//;
     my @func_args = @args;
@@ -546,14 +688,14 @@ EOF
     $func_args = join(", ", @func_args);
     @args_match{@args} = @args_num;
 
-    $PPCODE = grep(/^\s*PPCODE\s*:/, @line);
-    $CODE = grep(/^\s*CODE\s*:/, @line);
+    $PPCODE = grep(m/^\s*PPCODE\s*:/, @line);
+    $CODE = grep(m/^\s*CODE\s*:/, @line);
     # Detect CODE: blocks which use ST(n)= or XST_m*(n,v)
     #   to set explicit return values.
     $EXPLICIT_RETURN = ($CODE &&
-			("@line" =~ /(\bST\s*\([^;]*=) | (\bXST_m\w+\s*\()/x ));
-    $ALIAS  = grep(/^\s*ALIAS\s*:/,  @line);
-    $INTERFACE  = grep(/^\s*INTERFACE\s*:/,  @line);
+			("@line" =~ m/(\bST\s*\([^;]*=) | (\bXST_m\w+\s*\()/x ));
+    $ALIAS  = grep(m/^\s*ALIAS\s*:/,  @line);
+    $INTERFACE  = grep(m/^\s*INTERFACE\s*:/,  @line);
 
     $xsreturn = 1 if $EXPLICIT_RETURN;
 
@@ -663,7 +805,7 @@ EOF
       }
       
       # do code
-      if (/^\s*NOT_IMPLEMENTED_YET/) {
+      if (m/^\s*NOT_IMPLEMENTED_YET/) {
 	print "\n\tPerl_croak(aTHX_ \"$pname: not implemented yet\");\n";
 	$_ = '' ;
       } else {
@@ -731,7 +873,7 @@ EOF
       process_keyword("POSTCALL|OUTPUT|ALIAS|ATTRS|PROTOTYPE|OVERLOAD");
       
       &generate_output($var_types{$_}, $args_match{$_}, $_, $DoSetMagic)
-	for grep $in_out{$_} =~ /OUT$/, keys %in_out;
+	for grep $in_out{$_} =~ m/OUT$/, keys %in_out;
       
       # all OUTPUT done, so now push the return value on the stack
       if ($gotRETVAL && $RETVAL_code) {
@@ -802,7 +944,7 @@ EOF
 	next;
       }
       last if $_ eq "$END:";
-      death(/^$BLOCK_re/o ? "Misplaced `$1:'" : "Junk at end of function");
+      death(m/^$BLOCK_re/o ? "Misplaced `$1:'" : "Junk at end of function");
     }
     
     print Q(<<"EOF") if $except;
@@ -837,7 +979,7 @@ EOF
       }
       elsif ($ProtoThisXSUB eq 1) {
 	my $s = ';';
-	if ($min_args < $num_args)  {
+	if ($min_args +< $num_args)  {
 	  $s = '';
 	  $proto_arg[$min_args] .= ";" ;
 	}
@@ -874,7 +1016,7 @@ EOF
     }
     elsif ($interface) {
       while ( ($name, $value) = each %Interfaces) {
-	$name = "$Package\::$name" unless $name =~ /::/;
+	$name = "$Package\::$name" unless $name =~ m/::/;
 	push(@InitFileCode, Q(<<"EOF"));
 #        cv = newXS(\"$name\", XS_$Full_func_name, file);
 #        $interface_macro_set(cv,$value) ;
@@ -888,120 +1030,6 @@ EOF
       push(@InitFileCode,
 	   "        ${newXS}(\"$pname\", XS_$Full_func_name, file$proto);\n");
     }
-  }
-
-  if ($Overload) # make it findable with fetchmethod
-  {
-    print Q(<<"EOF");
-#XS(XS_${Packid}_nil); /* prototype to pass -Wmissing-prototypes */
-#XS(XS_${Packid}_nil)
-#{
-#   XSRETURN_EMPTY;
-#}
-#
-EOF
-    unshift(@InitFileCode, <<"MAKE_FETCHMETHOD_WORK");
-    /* Making a sub named "${Package}::()" allows the package */
-    /* to be findable via fetchmethod(), and causes */
-    /* overload::Overloaded("${Package}") to return true. */
-    newXS("${Package}::()", XS_${Packid}_nil, file$proto);
-MAKE_FETCHMETHOD_WORK
-  }
-
-  # print initialization routine
-
-  print Q(<<"EOF");
-##ifdef __cplusplus
-#extern "C"
-##endif
-EOF
-
-  print Q(<<"EOF");
-#XS(boot_$Module_cname); /* prototype to pass -Wmissing-prototypes */
-#XS(boot_$Module_cname)
-EOF
-
-  print Q(<<"EOF");
-#[[
-##ifdef dVAR
-#    dVAR; dXSARGS;
-##else
-#    dXSARGS;
-##endif
-EOF
-
-  #-Wall: if there is no $Full_func_name there are no xsubs in this .xs
-  #so `file' is unused
-  print Q(<<"EOF") if $Full_func_name;
-#    char* file = __FILE__;
-EOF
-
-  print Q("#\n");
-
-  print Q(<<"EOF");
-#    PERL_UNUSED_VAR(cv); /* -W */
-#    PERL_UNUSED_VAR(items); /* -W */
-EOF
-    
-  print Q(<<"EOF") if $WantVersionChk ;
-#    XS_VERSION_BOOTCHECK ;
-#
-EOF
-
-  print Q(<<"EOF") if defined $XsubAliases or defined $Interfaces ;
-#    {
-#        CV * cv ;
-#
-EOF
-
-  print Q(<<"EOF") if ($Overload);
-#    /* register the overloading (type 'A') magic */
-#    PL_amagic_generation++;
-#    /* The magic for overload gets a GV* via gv_fetchmeth as */
-#    /* mentioned above, and looks in the SV* slot of it for */
-#    /* the "fallback" status. */
-#    sv_setsv(
-#        get_sv( "${Package}::()", TRUE ),
-#        $Fallback
-#    );
-EOF
-
-  print @InitFileCode;
-
-  print Q(<<"EOF") if defined $XsubAliases or defined $Interfaces ;
-#    }
-EOF
-
-  if (@BootCode)
-  {
-    print "\n    /* Initialisation Section */\n\n" ;
-    @line = @BootCode;
-    print_section();
-    print "\n    /* End of Initialisation Section */\n\n" ;
-  }
-
-  if ($] >= 5.009) {
-    print <<'EOF';
-    if (PL_unitcheckav)
-         call_list(PL_scopestack_ix, PL_unitcheckav);
-EOF
-  }
-
-  print Q(<<"EOF");
-#    XSRETURN_YES;
-#]]
-#
-EOF
-
-  warn("Please specify prototyping behavior for $filename (see perlxs manual)\n")
-    unless $ProtoUsed ;
-
-  chdir($orig_cwd);
-  select($orig_fh);
-  untie *PSEUDO_STDOUT if tied *PSEUDO_STDOUT;
-  close $FH;
-
-  return 1;
 }
 
 sub errors { $errors }
@@ -1029,8 +1057,7 @@ sub TrimWhitespace
   $_[0] =~ s/^\s+|\s+$//go ;
 }
 
-sub TidyType
-  {
+sub TidyType {
     local ($_) = @_ ;
 
     # rationalise any '*' by joining them into bunches and removing whitespace
@@ -1050,17 +1077,17 @@ sub TidyType
 # Output: ($_, @line) == (rest of line, following lines).
 # Return: the matched keyword if found, otherwise 0
 sub check_keyword {
-	$_ = shift(@line) while !/\S/ && @line;
+	$_ = shift(@line) while !m/\S/ && @line;
 	s/^(\s*)($_[0])\s*:\s*(?:#.*)?/$1/s && $2;
 }
 
 sub print_section {
     # the "do" is required for right semantics
-    do { $_ = shift(@line) } while !/\S/ && @line;
+    do { $_ = shift(@line) } while !m/\S/ && @line;
 
     print("#line ", $line_no[@line_no - @line -1], " \"$filepathname\"\n")
-	if $WantLineNumbers && !/^\s*#\s*line\b/ && !/^#if XSubPPtmp/;
-    for (;  defined($_) && !/^$BLOCK_re/o;  $_ = shift(@line)) {
+	if $WantLineNumbers && !m/^\s*#\s*line\b/ && !m/^#if XSubPPtmp/;
+    for (;  defined($_) && !m/^$BLOCK_re/o;  $_ = shift(@line)) {
 	print "$_\n";
     }
     print 'ExtUtils::ParseXS::CountLines'->end_marker, "\n" if $WantLineNumbers;
@@ -1069,11 +1096,11 @@ sub print_section {
 sub merge_section {
     my $in = '';
 
-    while (!/\S/ && @line) {
+    while (!m/\S/ && @line) {
       $_ = shift(@line);
     }
 
-    for (;  defined($_) && !/^$BLOCK_re/o;  $_ = shift(@line)) {
+    for (;  defined($_) && !m/^$BLOCK_re/o;  $_ = shift(@line)) {
       $in .= "$_\n";
     }
     chomp $in;
@@ -1099,15 +1126,15 @@ sub CASE_handler {
 }
 
 sub INPUT_handler {
-  for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-    last if /^\s*NOT_IMPLEMENTED_YET/;
-    next unless /\S/;		# skip blank lines
+  for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+    last if m/^\s*NOT_IMPLEMENTED_YET/;
+    next unless m/\S/;		# skip blank lines
 
     TrimWhitespace($_) ;
     my $line = $_ ;
 
     # remove trailing semicolon if no initialisation
-    s/\s*;$//g unless /[=;+].*\S/ ;
+    s/\s*;$//g unless m/[=;+].*\S/ ;
 
     # Process the length(foo) declarations
     if (s/^([^=]*)\blength\(\s*(\w+)\s*\)\s*$/$1 XSauto_length_of_$2=NO_INIT/x) {
@@ -1123,7 +1150,7 @@ sub INPUT_handler {
     $var_init =~ s/"/\\"/g;
 
     s/\s+/ /g;
-    my ($var_type, $var_addr, $var_name) = /^(.*?[^&\s])\s*(\&?)\s*\b(\w+)$/s
+    my ($var_type, $var_addr, $var_name) = m/^(.*?[^&\s])\s*(\&?)\s*\b(\w+)$/s
       or blurt("Error: invalid argument declaration '$line'"), next;
 
     # Check for duplicate definitions
@@ -1137,7 +1164,7 @@ sub INPUT_handler {
     # XXXX This check is a safeguard against the unfinished conversion of
     # generate_init().  When generate_init() is fixed,
     # one can use 2-args map_type() unconditionally.
-    if ($var_type =~ / \( \s* \* \s* \) /x) {
+    if ($var_type =~ m/ \( \s* \* \s* \) /x) {
       # Function pointers are not yet supported with &output_init!
       print "\t" . &map_type($var_type, $var_name);
       $name_printed = 1;
@@ -1150,15 +1177,15 @@ sub INPUT_handler {
     $proto_arg[$var_num] = ProtoString($var_type)
       if $var_num ;
     $func_args =~ s/\b($var_name)\b/&$1/ if $var_addr;
-    if ($var_init =~ /^[=;]\s*NO_INIT\s*;?\s*$/
-	or $in_out{$var_name} and $in_out{$var_name} =~ /^OUT/
-	and $var_init !~ /\S/) {
+    if ($var_init =~ m/^[=;]\s*NO_INIT\s*;?\s*$/
+	or $in_out{$var_name} and $in_out{$var_name} =~ m/^OUT/
+	and $var_init !~ m/\S/) {
       if ($name_printed) {
 	print ";\n";
       } else {
 	print "\t$var_name;\n";
       }
-    } elsif ($var_init =~ /\S/) {
+    } elsif ($var_init =~ m/\S/) {
       &output_init($var_type, $var_num, $var_name, $var_init, $name_printed);
     } elsif ($var_num) {
       # generate initialization code
@@ -1170,13 +1197,13 @@ sub INPUT_handler {
 }
 
 sub OUTPUT_handler {
-  for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-    next unless /\S/;
-    if (/^\s*SETMAGIC\s*:\s*(ENABLE|DISABLE)\s*/) {
+  for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+    next unless m/\S/;
+    if (m/^\s*SETMAGIC\s*:\s*(ENABLE|DISABLE)\s*/) {
       $DoSetMagic = ($1 eq "ENABLE" ? 1 : 0);
       next;
     }
-    my ($outarg, $outcode) = /^\s*(\S+)\s*(.*?)\s*$/s ;
+    my ($outarg, $outcode) = m/^\s*(\S+)\s*(.*?)\s*$/s ;
     blurt ("Error: duplicate OUTPUT argument '$outarg' ignored"), next
       if $outargs{$outarg} ++ ;
     if (!$gotRETVAL and $outarg eq 'RETVAL') {
@@ -1197,7 +1224,7 @@ sub OUTPUT_handler {
       &generate_output($var_types{$outarg}, $var_num, $outarg, $DoSetMagic);
     }
     delete $in_out{$outarg} 	# No need to auto-OUTPUT
-      if exists $in_out{$outarg} and $in_out{$outarg} =~ /OUT$/;
+      if exists $in_out{$outarg} and $in_out{$outarg} =~ m/OUT$/;
   }
 }
 
@@ -1212,7 +1239,7 @@ sub INTERFACE_MACRO_handler() {
   my $in = merge_section();
 
   TrimWhitespace($in);
-  if ($in =~ /\s/) {		# two
+  if ($in =~ m/\s/) {		# two
     ($interface_macro, $interface_macro_set) = split ' ', $in;
   } else {
     $interface_macro = $in;
@@ -1227,7 +1254,7 @@ sub INTERFACE_handler() {
 
   TrimWhitespace($in);
 
-  foreach (split /[\s,]+/, $in) {
+  foreach (split m/[\s,]+/, $in) {
     my $name = $_;
     $name =~ s/^$Prefix//;
     $Interfaces{$name} = $_;
@@ -1261,7 +1288,7 @@ sub GetAliases
       $value = $2 ;
 
       # check for optional package definition in the alias
-      $alias = $Packprefix . $alias if $alias !~ /::/ ;
+      $alias = $Packprefix . $alias if $alias !~ m/::/ ;
 
       # check for duplicate alias name & duplicate value
       Warn("Warning: Ignoring duplicate alias '$orig_alias'")
@@ -1281,8 +1308,8 @@ sub GetAliases
 
 sub ATTRS_handler ()
   {
-    for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-      next unless /\S/;
+    for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+      next unless m/\S/;
       TrimWhitespace($_) ;
       push @Attributes, $_;
     }
@@ -1290,8 +1317,8 @@ sub ATTRS_handler ()
 
 sub ALIAS_handler ()
   {
-    for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-      next unless /\S/;
+    for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+      next unless m/\S/;
       TrimWhitespace($_) ;
       GetAliases($_) if $_ ;
     }
@@ -1299,8 +1326,8 @@ sub ALIAS_handler ()
 
 sub OVERLOAD_handler()
 {
-  for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-    next unless /\S/;
+  for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+    next unless m/\S/;
     TrimWhitespace($_) ;
     while ( s/^\s*([\w:"\\)\+\-\*\/\%\<\>\.\&\|\^\!\~\{\}\=]+)\s*//) {
       $Overload = 1 unless $Overload;
@@ -1342,10 +1369,10 @@ sub REQUIRE_handler ()
 
     # check that the version number is of the form n.n
     death ("Error: REQUIRE: expected a number, got '$Ver'")
-      unless $Ver =~ /^\d+(\.\d*)?/ ;
+      unless $Ver =~ m/^\d+(\.\d*)?/ ;
 
     death ("Error: xsubpp $Ver (or better) required--this is only $VERSION.")
-      unless $VERSION >= $Ver ;
+      unless $VERSION +>= $Ver ;
   }
 
 sub VERSIONCHECK_handler ()
@@ -1357,7 +1384,7 @@ sub VERSIONCHECK_handler ()
 
     # check for ENABLE/DISABLE
     death ("Error: VERSIONCHECK: ENABLE/DISABLE")
-      unless /^(ENABLE|DISABLE)/i ;
+      unless m/^(ENABLE|DISABLE)/i ;
 
     $WantVersionChk = 1 if $1 eq 'ENABLE' ;
     $WantVersionChk = 0 if $1 eq 'DISABLE' ;
@@ -1371,8 +1398,8 @@ sub PROTOTYPE_handler ()
     death("Error: Only 1 PROTOTYPE definition allowed per xsub")
       if $proto_in_this_xsub ++ ;
 
-    for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-      next unless /\S/;
+    for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+      next unless m/\S/;
       $specified = 1 ;
       TrimWhitespace($_) ;
       if ($_ eq 'DISABLE') {
@@ -1400,12 +1427,12 @@ sub SCOPE_handler ()
     death("Error: Only 1 SCOPE declaration allowed per xsub")
       if $scope_in_this_xsub ++ ;
 
-    for (;  !/^$BLOCK_re/o;  $_ = shift(@line)) {
-      next unless /\S/;
+    for (;  !m/^$BLOCK_re/o;  $_ = shift(@line)) {
+      next unless m/\S/;
       TrimWhitespace($_) ;
-      if ($_ =~ /^DISABLE/i) {
+      if ($_ =~ m/^DISABLE/i) {
 	$ScopeThisXSUB = 0
-      } elsif ($_ =~ /^ENABLE/i) {
+      } elsif ($_ =~ m/^ENABLE/i) {
 	$ScopeThisXSUB = 1
       }
     }
@@ -1421,7 +1448,7 @@ sub PROTOTYPES_handler ()
 
     # check for ENABLE/DISABLE
     death ("Error: PROTOTYPES: ENABLE/DISABLE")
-      unless /^(ENABLE|DISABLE)/i ;
+      unless m/^(ENABLE|DISABLE)/i ;
 
     $WantPrototypes = 1 if $1 eq 'ENABLE' ;
     $WantPrototypes = 0 if $1 eq 'DISABLE' ;
@@ -1439,13 +1466,13 @@ sub INCLUDE_handler ()
       unless $_ ;
 
     death("INCLUDE: output pipe is illegal")
-      if /^\s*\|/ ;
+      if m/^\s*\|/ ;
 
     # simple minded recursion detector
     death("INCLUDE loop detected")
       if $IncludedFiles{$_} ;
 
-    ++ $IncludedFiles{$_} unless /\|\s*$/ ;
+    ++ $IncludedFiles{$_} unless m/\|\s*$/ ;
 
     # Save the current file context.
     push(@XSStack, {
@@ -1462,7 +1489,7 @@ sub INCLUDE_handler ()
     $FH = Symbol::gensym();
 
     # open the new file
-    open ($FH, "$_") or death("Cannot open '$_': $!") ;
+    open ($FH, "<", "$_") or death("Cannot open '$_': $!") ;
 
     print Q(<<"EOF");
 #
@@ -1476,8 +1503,8 @@ EOF
     # non-blank line
 
     # skip leading blank lines
-    while (<$FH>) {
-      last unless /^\s*$/ ;
+    while ( ~< $FH) {
+      last unless m/^\s*$/ ;
     }
 
     $lastline = $_ ;
@@ -1491,7 +1518,7 @@ sub PopFile()
 
     my $data     = pop @XSStack ;
     my $ThisFile = $filename ;
-    my $isPipe   = ($filename =~ /\|\s*$/) ;
+    my $isPipe   = ($filename =~ m/\|\s*$/) ;
 
     -- $IncludedFiles{$filename}
       unless $isPipe ;
@@ -1528,7 +1555,7 @@ sub ValidProtoString ($)
   {
     my($string) = @_ ;
 
-    if ( $string =~ /^$proto_re+$/ ) {
+    if ( $string =~ m/^$proto_re+$/ ) {
       return $string ;
     }
 
@@ -1551,18 +1578,18 @@ sub ProtoString ($)
   }
 
 sub check_cpp {
-  my @cpp = grep(/^\#\s*(?:if|e\w+)/, @line);
+  my @cpp = grep(m/^\#\s*(?:if|e\w+)/, @line);
   if (@cpp) {
     my ($cpp, $cpplevel);
     for $cpp (@cpp) {
-      if ($cpp =~ /^\#\s*if/) {
+      if ($cpp =~ m/^\#\s*if/) {
 	$cpplevel++;
       } elsif (!$cpplevel) {
 	Warn("Warning: #else/elif/endif without #if in this function");
 	print STDERR "    (precede it with a blank line if the matching #if is outside the function)\n"
 	  if $XSStack[-1]{type} eq 'if';
 	return;
-      } elsif ($cpp =~ /^\#\s*endif/) {
+      } elsif ($cpp =~ m/^\#\s*endif/) {
 	$cpplevel--;
       }
     }
@@ -1574,8 +1601,8 @@ sub check_cpp {
 sub Q {
   my($text) = @_;
   $text =~ s/^#//gm;
-  $text =~ s/\[\[/{/g;
-  $text =~ s/\]\]/}/g;
+  $text =~ s/\[\[/\{/g;
+  $text =~ s/\]\]/\}/g;
   $text;
 }
 
@@ -1589,7 +1616,7 @@ sub fetch_para {
   return PopFile() if !defined $lastline;
 
   if ($lastline =~
-      /^MODULE\s*=\s*([\w:]+)(?:\s+PACKAGE\s*=\s*([\w:]+))?(?:\s+PREFIX\s*=\s*(\S+))?\s*$/) {
+      m/^MODULE\s*=\s*([\w:]+)(?:\s+PACKAGE\s*=\s*([\w:]+))?(?:\s+PREFIX\s*=\s*(\S+))?\s*$/) {
     $Module = $1;
     $Package = defined($2) ? $2 : ''; # keep -w happy
     $Prefix  = defined($3) ? $3 : ''; # keep -w happy
@@ -1603,34 +1630,34 @@ sub fetch_para {
 
   for (;;) {
     # Skip embedded PODs
-    while ($lastline =~ /^=/) {
-      while ($lastline = <$FH>) {
-	last if ($lastline =~ /^=cut\s*$/);
+    while ($lastline =~ m/^=/) {
+      while ($lastline = ~< $FH) {
+	last if ($lastline =~ m/^=cut\s*$/);
       }
       death ("Error: Unterminated pod") unless $lastline;
-      $lastline = <$FH>;
+      $lastline = ~< $FH;
       chomp $lastline;
       $lastline =~ s/^\s+$//;
     }
-    if ($lastline !~ /^\s*#/ ||
+    if ($lastline !~ m/^\s*#/ ||
 	# CPP directives:
 	#	ANSI:	if ifdef ifndef elif else endif define undef
 	#		line error pragma
 	#	gcc:	warning include_next
 	#   obj-c:	import
 	#   others:	ident (gcc notes that some cpps have this one)
-	$lastline =~ /^#[ \t]*(?:(?:if|ifn?def|elif|else|endif|define|undef|pragma|error|warning|line\s+\d+|ident)\b|(?:include(?:_next)?|import)\s*["<].*[>"])/) {
-      last if $lastline =~ /^\S/ && @line && $line[-1] eq "";
+	$lastline =~ m/^#[ \t]*(?:(?:if|ifn?def|elif|else|endif|define|undef|pragma|error|warning|line\s+\d+|ident)\b|(?:include(?:_next)?|import)\s*["<].*[>"])/) {
+      last if $lastline =~ m/^\S/ && @line && $line[-1] eq "";
       push(@line, $lastline);
       push(@line_no, $lastline_no) ;
     }
 
     # Read next line and continuation lines
-    last unless defined($lastline = <$FH>);
+    last unless defined($lastline = ~< $FH);
     $lastline_no = $.;
     my $tmp_line;
     $lastline .= $tmp_line
-      while ($lastline =~ /\\$/ && defined($tmp_line = <$FH>));
+      while ($lastline =~ m/\\$/ && defined($tmp_line = ~< $FH));
 
     chomp $lastline;
     $lastline =~ s/^\s+$//;
@@ -1643,26 +1670,27 @@ sub output_init {
   local($type, $num, $var, $init, $name_printed) = @_;
   local($arg) = "ST(" . ($num - 1) . ")";
 
-  if (  $init =~ /^=/  ) {
-    if ($name_printed) {
-      eval qq/print " $init\\n"/;
-    } else {
-      eval qq/print "\\t$var $init\\n"/;
-    }
-    warn $@   if  $@;
+  if (  $init =~ m/^=/  ) {
+      my $x_init = evalqq($init);
+      if ($name_printed) {
+          print " $x_init\n";
+      } else {
+          my $x_var = evalqq($var);
+          print "\t$x_var $x_init\n";
+      }
   } else {
     if (  $init =~ s/^\+//  &&  $num  ) {
-      &generate_init($type, $num, $var, $name_printed);
+        &generate_init($type, $num, $var, $name_printed);
     } elsif ($name_printed) {
-      print ";\n";
-      $init =~ s/^;//;
+        print ";\n";
+        $init =~ s/^;//;
     } else {
-      eval qq/print "\\t$var;\\n"/;
-      warn $@   if  $@;
-      $init =~ s/^;//;
+        my $x_var = evalqq($var);
+        print "\t$x_var;\n";
+        $init =~ s/^;//;
     }
-    $deferred .= eval qq/"\\n\\t$init\\n"/;
-    warn $@   if  $@;
+    my $x_init = evalqq($init);
+    $deferred .= "\n\t$x_init\n";
   }
 }
 
@@ -1683,9 +1711,16 @@ sub blurt
 sub death
   {
     Warn @_ ;
-    exit 1 ;
+    die @_;
   }
 
+sub evalqq {
+    my $x = shift;
+    my $ex = eval qq/"$x"/;
+    die "error in '$x': $@" if $@;
+    return $ex;
+}
+
 sub generate_init {
   local($type, $num, $var) = @_;
   local($arg) = "ST(" . ($num - 1) . ")";
@@ -1700,7 +1735,7 @@ sub generate_init {
   ($ntype = $type) =~ s/\s*\*/Ptr/g;
   ($subtype = $ntype) =~ s/(?:Array)?(?:Ptr)?$//;
   $tk = $type_kind{$type};
-  $tk =~ s/OBJ$/REF/ if $func_name =~ /DESTROY$/;
+  $tk =~ s/OBJ$/REF/ if $func_name =~ m/DESTROY$/;
   if ($tk eq 'T_PV' and exists $lengthof{$var}) {
     print "\t$var" unless $name_printed;
     print " = ($type)SvPV($arg, STRLEN_length_of_$var);\n";
@@ -1712,7 +1747,7 @@ sub generate_init {
   blurt("Error: No INPUT definition for type '$type', typekind '$type_kind{$type}' found"), return
     unless defined $input_expr{$tk} ;
   $expr = $input_expr{$tk};
-  if ($expr =~ /DO_ARRAY_ELEM/) {
+  if ($expr =~ m/DO_ARRAY_ELEM/) {
     blurt("Error: '$subtype' not in typemap"), return
       unless defined($type_kind{$subtype});
     blurt("Error: No INPUT definition for type '$subtype', typekind '$type_kind{$subtype}' found"), return
@@ -1729,35 +1764,36 @@ sub generate_init {
   if ($expr =~ m#/\*.*scope.*\*/#i) {  # "scope" in C comments
     $ScopeThisXSUB = 1;
   }
+  my $x_var = evalqq($var);
   if (defined($defaults{$var})) {
     $expr =~ s/(\t+)/$1    /g;
     $expr =~ s/        /\t/g;
     if ($name_printed) {
       print ";\n";
     } else {
-      eval qq/print "\\t$var;\\n"/;
-      warn $@   if  $@;
+      print "\t$x_var;\n";
     }
+    my $x_num = evalqq($num);
+    my $x_expr = evalqq($expr);
     if ($defaults{$var} eq 'NO_INIT') {
-      $deferred .= eval qq/"\\n\\tif (items >= $num) {\\n$expr;\\n\\t}\\n"/;
+        $deferred .= qq/\n\tif (items >= $x_num) \{\n$x_expr;\n\t\}\n/;
     } else {
-      $deferred .= eval qq/"\\n\\tif (items < $num)\\n\\t    $var = $defaults{$var};\\n\\telse {\\n$expr;\\n\\t}\\n"/;
+        my $x_defaults_var = evalqq($defaults{$var});
+        $deferred .= qq/\n\tif (items < $x_num)\n\t    $x_var = $x_defaults_var;\n\telse \{\n$x_expr;\n\t\}\n/;
     }
-    warn $@   if  $@;
-  } elsif ($ScopeThisXSUB or $expr !~ /^\s*\$var =/) {
+  } elsif ($ScopeThisXSUB or $expr !~ m/^\s*\$var =/) {
     if ($name_printed) {
       print ";\n";
     } else {
-      eval qq/print "\\t$var;\\n"/;
-      warn $@   if  $@;
+      print "\t$x_var;\n";
     }
-    $deferred .= eval qq/"\\n$expr;\\n"/;
-    warn $@   if  $@;
+    my $x_expr = evalqq($expr);
+    $deferred .= "\n$x_expr;\n";
   } else {
     die "panic: do not know how to handle this branch for function pointers"
       if $name_printed;
-    eval qq/print "$expr;\\n"/;
-    warn $@   if  $@;
+    my $x_expr = evalqq($expr);
+    print "$x_expr;\n";
   }
 }
 
@@ -1768,7 +1804,7 @@ sub generate_output {
   local($ntype);
 
   $type = TidyType($type) ;
-  if ($type =~ /^array\(([^,]*),(.*)\)/) {
+  if ($type =~ m/^array\(([^,]*),(.*)\)/) {
     print "\t$arg = sv_newmortal();\n";
     print "\tsv_setpvn($arg, (char *)$var, $2 * sizeof($1));\n";
     print "\tSvSETMAGIC($arg);\n" if $do_setmagic;
@@ -1781,7 +1817,7 @@ sub generate_output {
     $ntype =~ s/\(\)//g;
     ($subtype = $ntype) =~ s/(?:Array)?(?:Ptr)?$//;
     $expr = $output_expr{$type_kind{$type}};
-    if ($expr =~ /DO_ARRAY_ELEM/) {
+    if ($expr =~ m/DO_ARRAY_ELEM/) {
       blurt("Error: '$subtype' not in typemap"), return
 	unless defined($type_kind{$subtype});
       blurt("Error: No OUTPUT definition for type '$subtype', typekind '$type_kind{$subtype}' found"), return
@@ -1796,14 +1832,14 @@ sub generate_output {
       warn $@   if  $@;
       print "\t\tSvSETMAGIC(ST(ix_$var));\n" if $do_setmagic;
     } elsif ($var eq 'RETVAL') {
-      if ($expr =~ /^\t\$arg = new/) {
+      if ($expr =~ m/^\t\$arg = new/) {
 	# We expect that $arg has refcnt 1, so we need to
 	# mortalize it.
 	eval "print qq\a$expr\a";
 	warn $@   if  $@;
 	print "\tsv_2mortal(ST($num));\n";
 	print "\tSvSETMAGIC(ST($num));\n" if $do_setmagic;
-      } elsif ($expr =~ /^\s*\$arg\s*=/) {
+      } elsif ($expr =~ m/^\s*\$arg\s*=/) {
 	# We expect that $arg has refcnt >=1, so we need
 	# to mortalize it!
 	eval "print qq\a$expr\a";
@@ -1826,7 +1862,7 @@ sub generate_output {
       eval "print qq\a$expr\a";
       warn $@   if  $@;
       print "\tSvSETMAGIC($arg);\n" if $do_setmagic;
-    } elsif ($arg =~ /^ST\(\d+\)$/) {
+    } elsif ($arg =~ m/^ST\(\d+\)$/) {
       eval "print qq\a$expr\a";
       warn $@   if  $@;
       print "\tSvSETMAGIC($arg);\n" if $do_setmagic;
@@ -1841,8 +1877,8 @@ sub map_type {
   $type =~ tr/:/_/ unless $hiertype;
   $type =~ s/^array\(([^,]*),(.*)\).*/$1 */s;
   if ($varname) {
-    if ($varname && $type =~ / \( \s* \* (?= \s* \) ) /xg) {
-      (substr $type, pos $type, 0) = " $varname ";
+    if ($varname && $type =~ m/ \( \s* \* (?= \s* \) ) /xg) {
+      substr $type, pos $type, 0, " $varname ";
     } else {
       $type .= "\t$varname";
     }
@@ -1855,7 +1891,7 @@ sub map_type {
 package
   ExtUtils::ParseXS::CountLines;
 use strict;
-use vars qw($SECTION_END_MARKER);
+our ($SECTION_END_MARKER);
 
 sub TIEHANDLE {
   my ($class, $cfile, $fh) = @_;
