@@ -137,7 +137,7 @@ sub import {
 # Values for $order. See GNU getopt.c for details.
 ($REQUIRE_ORDER, $PERMUTE, $RETURN_IN_ORDER) = (0..2);
 # Version major/minor numbers.
-($major_version, $minor_version) = $VERSION =~ /^(\d+)\.(\d+)/;
+($major_version, $minor_version) = $VERSION =~ m/^(\d+)\.(\d+)/;
 
 ConfigDefaults();
 
@@ -336,9 +336,9 @@ sub GetOptionsFromArray($@) {
     # See if the first element of the optionlist contains option
     # starter characters.
     # Be careful not to interpret '<>' as option starters.
-    if ( @optionlist && $optionlist[0] =~ /^\W+$/
+    if ( @optionlist && $optionlist[0] =~ m/^\W+$/
 	 && !($optionlist[0] eq '<>'
-	      && @optionlist > 0
+	      && @optionlist +> 0
 	      && ref($optionlist[1])) ) {
 	$prefix = shift (@optionlist);
 	# Turn into regexp. Needs to be parenthesized!
@@ -358,16 +358,16 @@ sub GetOptionsFromArray($@) {
 	}
 
 	# Strip leading prefix so people can specify "--foo=i" if they like.
-	$opt = $+ if $opt =~ /^$prefix+(.*)$/s;
+	$opt = $+ if $opt =~ m/^$prefix+(.*)$/s;
 
 	if ( $opt eq '<>' ) {
 	    if ( (defined $userlinkage)
-		&& !(@optionlist > 0 && ref($optionlist[0]))
+		&& !(@optionlist +> 0 && ref($optionlist[0]))
 		&& (exists $userlinkage->{$opt})
 		&& ref($userlinkage->{$opt}) ) {
 		unshift (@optionlist, $userlinkage->{$opt});
 	    }
-	    unless ( @optionlist > 0
+	    unless ( @optionlist +> 0
 		    && ref($optionlist[0]) && ref($optionlist[0]) eq 'CODE' ) {
 		$error .= "Option spec <> requires a reference to a subroutine\n";
 		# Kill the linkage (to avoid another error).
@@ -393,7 +393,7 @@ sub GetOptionsFromArray($@) {
 	# If no linkage is supplied in the @optionlist, copy it from
 	# the userlinkage if available.
 	if ( defined $userlinkage ) {
-	    unless ( @optionlist > 0 && ref($optionlist[0]) ) {
+	    unless ( @optionlist +> 0 && ref($optionlist[0]) ) {
 		if ( exists $userlinkage->{$orig} &&
 		     ref($userlinkage->{$orig}) ) {
 		    print STDERR ("=> found userlinkage for \"$orig\": ",
@@ -409,7 +409,7 @@ sub GetOptionsFromArray($@) {
 	}
 
 	# Copy the linkage. If omitted, link to global variable.
-	if ( @optionlist > 0 && ref($optionlist[0]) ) {
+	if ( @optionlist +> 0 && ref($optionlist[0]) ) {
 	    print STDERR ("=> link \"$orig\" to $optionlist[0]\n")
 		if $debug;
 	    my $rl = ref($linkage{$orig} = shift (@optionlist));
@@ -446,17 +446,17 @@ sub GetOptionsFromArray($@) {
 	    if ( $opctl{$name}[CTL_DEST] == CTL_DEST_ARRAY ) {
 		print STDERR ("=> link \"$orig\" to \@$pkg","::opt_$ov\n")
 		    if $debug;
-		eval ("\$linkage{\$orig} = \\\@".$pkg."::opt_$ov;");
+		eval ("\$linkage\{\$orig\} = \\\@".$pkg."::opt_$ov;");
 	    }
 	    elsif ( $opctl{$name}[CTL_DEST] == CTL_DEST_HASH ) {
 		print STDERR ("=> link \"$orig\" to \%$pkg","::opt_$ov\n")
 		    if $debug;
-		eval ("\$linkage{\$orig} = \\\%".$pkg."::opt_$ov;");
+		eval ("\$linkage\{\$orig\} = \\\%".$pkg."::opt_$ov;");
 	    }
 	    else {
 		print STDERR ("=> link \"$orig\" to \$$pkg","::opt_$ov\n")
 		    if $debug;
-		eval ("\$linkage{\$orig} = \\\$".$pkg."::opt_$ov;");
+		eval ("\$linkage\{\$orig\} = \\\$".$pkg."::opt_$ov;");
 	    }
 	}
     }
@@ -466,14 +466,14 @@ sub GetOptionsFromArray($@) {
     $error = 0;
 
     # Supply --version and --help support, if needed and allowed.
-    if ( defined($auto_version) ? $auto_version : ($requested_version >= 2.3203) ) {
+    if ( defined($auto_version) ? $auto_version : ($requested_version +>= 2.3203) ) {
 	if ( !defined($opctl{version}) ) {
 	    $opctl{version} = ['','version',0,CTL_DEST_CODE,undef];
 	    $linkage{version} = \&VersionMessage;
 	}
 	$auto_version = 1;
     }
-    if ( defined($auto_help) ? $auto_help : ($requested_version >= 2.3203) ) {
+    if ( defined($auto_help) ? $auto_help : ($requested_version +>= 2.3203) ) {
 	if ( !defined($opctl{help}) && !defined($opctl{'?'}) ) {
 	    $opctl{help} = $opctl{'?'} = ['','help',0,CTL_DEST_CODE,undef];
 	    $linkage{help} = \&HelpMessage;
@@ -486,14 +486,14 @@ sub GetOptionsFromArray($@) {
 	my ($arrow, $k, $v);
 	$arrow = "=> ";
 	while ( ($k,$v) = each(%opctl) ) {
-	    print STDERR ($arrow, "\$opctl{$k} = $v ", OptCtl($v), "\n");
+	    print STDERR ($arrow, "\$opctl\{$k\} = $v ", OptCtl($v), "\n");
 	    $arrow = "   ";
 	}
     }
 
     # Process argument list
     my $goon = 1;
-    while ( $goon && @$argv > 0 ) {
+    while ( $goon && @$argv +> 0 ) {
 
 	# Get next argument.
 	$opt = shift (@$argv);
@@ -529,13 +529,13 @@ sub GetOptionsFromArray($@) {
 		print STDERR ("\"$ctl->[CTL_CNAME]\"\n") if $debug;
 
 		if ( defined $linkage{$opt} ) {
-		    print STDERR ("=> ref(\$L{$opt}) -> ",
+		    print STDERR ("=> ref(\$L\{$opt\}) -> ",
 				  ref($linkage{$opt}), "\n") if $debug;
 
 		    if ( ref($linkage{$opt}) eq 'SCALAR'
 			 || ref($linkage{$opt}) eq 'REF' ) {
 			if ( $ctl->[CTL_TYPE] eq '+' ) {
-			    print STDERR ("=> \$\$L{$opt} += \"$arg\"\n")
+			    print STDERR ("=> \$\$L\{$opt\} += \"$arg\"\n")
 			      if $debug;
 			    if ( defined ${$linkage{$opt}} ) {
 			        ${$linkage{$opt}} += $arg;
@@ -545,43 +545,43 @@ sub GetOptionsFromArray($@) {
 			    }
 			}
 			elsif ( $ctl->[CTL_DEST] == CTL_DEST_ARRAY ) {
-			    print STDERR ("=> ref(\$L{$opt}) auto-vivified",
+			    print STDERR ("=> ref(\$L\{$opt\}) auto-vivified",
 					  " to ARRAY\n")
 			      if $debug;
 			    my $t = $linkage{$opt};
 			    $$t = $linkage{$opt} = [];
-			    print STDERR ("=> push(\@{\$L{$opt}, \"$arg\")\n")
+			    print STDERR ("=> push(\@\{\$L\{$opt\}, \"$arg\")\n")
 			      if $debug;
 			    push (@{$linkage{$opt}}, $arg);
 			}
 			elsif ( $ctl->[CTL_DEST] == CTL_DEST_HASH ) {
-			    print STDERR ("=> ref(\$L{$opt}) auto-vivified",
+			    print STDERR ("=> ref(\$L\{$opt\}) auto-vivified",
 					  " to HASH\n")
 			      if $debug;
 			    my $t = $linkage{$opt};
 			    $$t = $linkage{$opt} = {};
-			    print STDERR ("=> \$\$L{$opt}->{$key} = \"$arg\"\n")
+			    print STDERR ("=> \$\$L\{$opt\}->\{$key\} = \"$arg\"\n")
 			      if $debug;
 			    $linkage{$opt}->{$key} = $arg;
 			}
 			else {
-			    print STDERR ("=> \$\$L{$opt} = \"$arg\"\n")
+			    print STDERR ("=> \$\$L\{$opt\} = \"$arg\"\n")
 			      if $debug;
 			    ${$linkage{$opt}} = $arg;
 		        }
 		    }
 		    elsif ( ref($linkage{$opt}) eq 'ARRAY' ) {
-			print STDERR ("=> push(\@{\$L{$opt}, \"$arg\")\n")
+			print STDERR ("=> push(\@\{\$L\{$opt\}, \"$arg\")\n")
 			    if $debug;
 			push (@{$linkage{$opt}}, $arg);
 		    }
 		    elsif ( ref($linkage{$opt}) eq 'HASH' ) {
-			print STDERR ("=> \$\$L{$opt}->{$key} = \"$arg\"\n")
+			print STDERR ("=> \$\$L\{$opt\}->\{$key\} = \"$arg\"\n")
 			    if $debug;
 			$linkage{$opt}->{$key} = $arg;
 		    }
 		    elsif ( ref($linkage{$opt}) eq 'CODE' ) {
-			print STDERR ("=> &L{$opt}(\"$opt\"",
+			print STDERR ("=> &L\{$opt\}(\"$opt\"",
 				      $ctl->[CTL_DEST] == CTL_DEST_HASH ? ", \"$key\"" : "",
 				      ", \"$arg\")\n")
 			    if $debug;
@@ -604,8 +604,8 @@ sub GetOptionsFromArray($@) {
 			};
 			print STDERR ("=> die($eval_error)\n")
 			  if $debug && $eval_error ne '';
-			if ( $eval_error =~ /^!/ ) {
-			    if ( $eval_error =~ /^!FINISH\b/ ) {
+			if ( $eval_error =~ m/^!/ ) {
+			    if ( $eval_error =~ m/^!FINISH\b/ ) {
 				$goon = 0;
 			    }
 			}
@@ -623,31 +623,31 @@ sub GetOptionsFromArray($@) {
 		# No entry in linkage means entry in userlinkage.
 		elsif ( $ctl->[CTL_DEST] == CTL_DEST_ARRAY ) {
 		    if ( defined $userlinkage->{$opt} ) {
-			print STDERR ("=> push(\@{\$L{$opt}}, \"$arg\")\n")
+			print STDERR ("=> push(\@\{\$L\{$opt\}\}, \"$arg\")\n")
 			    if $debug;
 			push (@{$userlinkage->{$opt}}, $arg);
 		    }
 		    else {
-			print STDERR ("=>\$L{$opt} = [\"$arg\"]\n")
+			print STDERR ("=>\$L\{$opt\} = [\"$arg\"]\n")
 			    if $debug;
 			$userlinkage->{$opt} = [$arg];
 		    }
 		}
 		elsif ( $ctl->[CTL_DEST] == CTL_DEST_HASH ) {
 		    if ( defined $userlinkage->{$opt} ) {
-			print STDERR ("=> \$L{$opt}->{$key} = \"$arg\"\n")
+			print STDERR ("=> \$L\{$opt\}->\{$key\} = \"$arg\"\n")
 			    if $debug;
 			$userlinkage->{$opt}->{$key} = $arg;
 		    }
 		    else {
-			print STDERR ("=>\$L{$opt} = {$key => \"$arg\"}\n")
+			print STDERR ("=>\$L\{$opt\} = \{$key => \"$arg\"\}\n")
 			    if $debug;
 			$userlinkage->{$opt} = {$key => $arg};
 		    }
 		}
 		else {
 		    if ( $ctl->[CTL_TYPE] eq '+' ) {
-			print STDERR ("=> \$L{$opt} += \"$arg\"\n")
+			print STDERR ("=> \$L\{$opt\} += \"$arg\"\n")
 			  if $debug;
 			if ( defined $userlinkage->{$opt} ) {
 			    $userlinkage->{$opt} += $arg;
@@ -657,22 +657,22 @@ sub GetOptionsFromArray($@) {
 			}
 		    }
 		    else {
-			print STDERR ("=>\$L{$opt} = \"$arg\"\n") if $debug;
+			print STDERR ("=>\$L\{$opt\} = \"$arg\"\n") if $debug;
 			$userlinkage->{$opt} = $arg;
 		    }
 		}
 
 		$argcnt++;
-		last if $argcnt >= $ctl->[CTL_AMAX] && $ctl->[CTL_AMAX] != -1;
+		last if $argcnt +>= $ctl->[CTL_AMAX] && $ctl->[CTL_AMAX] != -1;
 		undef($arg);
 
 		# Need more args?
-		if ( $argcnt < $ctl->[CTL_AMIN] ) {
+		if ( $argcnt +< $ctl->[CTL_AMIN] ) {
 		    if ( @$argv ) {
 			if ( ValidValue($ctl, $argv->[0], 1, $argend, $prefix) ) {
 			    $arg = shift(@$argv);
-			    $arg =~ tr/_//d if $ctl->[CTL_TYPE] =~ /^[iIo]$/;
-			    ($key,$arg) = $arg =~ /^([^=]+)=(.*)/
+			    $arg =~ tr/_//d if $ctl->[CTL_TYPE] =~ m/^[iIo]$/;
+			    ($key,$arg) = $arg =~ m/^([^=]+)=(.*)/
 			      if $ctl->[CTL_DEST] == CTL_DEST_HASH;
 			    next;
 			}
@@ -688,8 +688,8 @@ sub GetOptionsFromArray($@) {
 		# Any more args?
 		if ( @$argv && ValidValue($ctl, $argv->[0], 0, $argend, $prefix) ) {
 		    $arg = shift(@$argv);
-		    $arg =~ tr/_//d if $ctl->[CTL_TYPE] =~ /^[iIo]$/;
-		    ($key,$arg) = $arg =~ /^([^=]+)=(.*)/
+		    $arg =~ tr/_//d if $ctl->[CTL_TYPE] =~ m/^[iIo]$/;
+		    ($key,$arg) = $arg =~ m/^([^=]+)=(.*)/
 		      if $ctl->[CTL_DEST] == CTL_DEST_HASH;
 		    next;
 		}
@@ -701,7 +701,7 @@ sub GetOptionsFromArray($@) {
 	    # Try non-options call-back.
 	    my $cb;
 	    if ( (defined ($cb = $linkage{'<>'})) ) {
-		print STDERR ("=> &L{$tryopt}(\"$tryopt\")\n")
+		print STDERR ("=> &L\{$tryopt\}(\"$tryopt\")\n")
 		  if $debug;
 		my $eval_error = do {
 		    local $@;
@@ -711,8 +711,8 @@ sub GetOptionsFromArray($@) {
 		};
 		print STDERR ("=> die($eval_error)\n")
 		  if $debug && $eval_error ne '';
-		if ( $eval_error =~ /^!/ ) {
-		    if ( $eval_error =~ /^!FINISH\b/ ) {
+		if ( $eval_error =~ m/^!/ ) {
+		    if ( $eval_error =~ m/^!FINISH\b/ ) {
 			$goon = 0;
 		    }
 		}
@@ -805,7 +805,7 @@ sub ParseOptionSpec ($$) {
 
     my @names;
     if ( defined $names ) {
-	@names =  split (/\|/, $names);
+	@names =  split (m/\|/, $names);
 	$orig = $names[0];
     }
     else {
@@ -819,7 +819,7 @@ sub ParseOptionSpec ($$) {
 	# Fields are hard-wired here.
 	$entry = [$spec,$orig,undef,CTL_DEST_SCALAR,0,0];
     }
-    elsif ( $spec =~ /^:(-?\d+|\+)([@%])?$/ ) {
+    elsif ( $spec =~ m/^:(-?\d+|\+)([@%])?$/ ) {
 	my $def = $1;
 	my $dest = $2;
 	my $type = $def eq '+' ? 'I' : 'i';
@@ -832,11 +832,11 @@ sub ParseOptionSpec ($$) {
     }
     else {
 	my ($mand, $type, $dest) =
-	  $spec =~ /^([=:])([ionfs])([@%])?(\{(\d+)?(,)?(\d+)?\})?$/;
+	  $spec =~ m/^([=:])([ionfs])([@%])?(\{(\d+)?(,)?(\d+)?\})?$/;
 	return (undef, "Cannot repeat while bundling: \"$opt\"\n")
 	  if $bundling && defined($4);
 	my ($mi, $cm, $ma) = ($5, $6, $7);
-	return (undef, "{0} is useless in option spec: \"$opt\"\n")
+	return (undef, "\{0\} is useless in option spec: \"$opt\"\n")
 	  if defined($mi) && !$mi && !defined($ma) && !defined($cm);
 
 	$type = 'i' if $type eq 'n';
@@ -852,7 +852,7 @@ sub ParseOptionSpec ($$) {
 	return (undef, "Max must be greater than zero in option spec: \"$opt\"\n")
 	  if defined($ma) && !$ma;
 	return (undef, "Max less than min in option spec: \"$opt\"\n")
-	  if defined($ma) && $ma < $mi;
+	  if defined($ma) && $ma +< $mi;
 
 	# Fields are hard-wired here.
 	$entry = [$type,$orig,undef,$dest,$mi,$ma||-1];
@@ -863,7 +863,7 @@ sub ParseOptionSpec ($$) {
     foreach ( @names ) {
 
 	$_ = lc ($_)
-	  if $ignorecase > (($bundling && length($_) == 1) ? 1 : 0);
+	  if $ignorecase +> (($bundling && length($_) == 1) ? 1 : 0);
 
 	if ( exists $opctl->{$_} ) {
 	    $dups .= "Duplicate specification \"$opt\" for option \"$_\"\n";
@@ -881,7 +881,7 @@ sub ParseOptionSpec ($$) {
     }
 
     if ( $dups && $^W ) {
-	foreach ( split(/\n+/, $dups) ) {
+	foreach ( split(m/\n+/, $dups) ) {
 	    warn($_."\n");
 	}
     }
@@ -899,7 +899,7 @@ sub FindOption ($$$$$) {
 
     print STDERR ("=> find \"$opt\"\n") if $debug;
 
-    return (0) unless $opt =~ /^$prefix(.*)$/s;
+    return (0) unless $opt =~ m/^$prefix(.*)$/s;
     return (0) if $opt eq "-" && !defined $opctl->{''};
 
     $opt = $+;
@@ -912,9 +912,9 @@ sub FindOption ($$$$$) {
 
     # If it is a long option, it may include the value.
     # With getopt_compat, only if not bundling.
-    if ( ($starter=~/^$longprefix$/
+    if ( ($starter=~m/^$longprefix$/
           || ($getopt_compat && ($bundling == 0 || $bundling == 2)))
-	  && $opt =~ /^([^=]+)=(.*)$/s ) {
+	  && $opt =~ m/^([^=]+)=(.*)$/s ) {
 	$opt = $1;
 	$optarg = $2;
 	print STDERR ("=> option \"", $opt,
@@ -931,7 +931,7 @@ sub FindOption ($$$$$) {
 	$tryopt = $ignorecase ? lc($opt) : $opt;
 
 	# If bundling == 2, long options can override bundles.
-	if ( $bundling == 2 && length($tryopt) > 1
+	if ( $bundling == 2 && length($tryopt) +> 1
 	     && defined ($opctl->{$tryopt}) ) {
 	    print STDERR ("=> $starter$tryopt overrides unbundling\n")
 	      if $debug;
@@ -939,9 +939,9 @@ sub FindOption ($$$$$) {
 	else {
 	    $tryopt = $opt;
 	    # Unbundle single letter option.
-	    $rest = length ($tryopt) > 0 ? substr ($tryopt, 1) : '';
+	    $rest = length ($tryopt) +> 0 ? substr ($tryopt, 1) : '';
 	    $tryopt = substr ($tryopt, 0, 1);
-	    $tryopt = lc ($tryopt) if $ignorecase > 1;
+	    $tryopt = lc ($tryopt) if $ignorecase +> 1;
 	    print STDERR ("=> $starter$tryopt unbundled from ",
 			  "$starter$tryopt$rest\n") if $debug;
 	    $rest = undef unless $rest ne '';
@@ -958,12 +958,12 @@ sub FindOption ($$$$$) {
 	# Turn option name into pattern.
 	my $pat = quotemeta ($opt);
 	# Look up in option names.
-	my @hits = grep (/^$pat/, @names);
+	my @hits = grep (m/^$pat/, @names);
 	print STDERR ("=> ", scalar(@hits), " hits (@hits) with \"$pat\" ",
 		      "out of ", scalar(@names), "\n") if $debug;
 
 	# Check for ambiguous results.
-	unless ( (@hits <= 1) || (grep ($_ eq $opt, @hits) == 1) ) {
+	unless ( (@hits +<= 1) || (grep ($_ eq $opt, @hits) == 1) ) {
 	    # See if all matches are for the same option.
 	    my %hit;
 	    foreach ( @hits ) {
@@ -1061,7 +1061,7 @@ sub FindOption ($$$$$) {
     # Check if there is an option argument available.
     if ( defined $optarg
 	 ? ($optarg eq '')
-	 : !(defined $rest || @$argv > 0) ) {
+	 : !(defined $rest || @$argv +> 0) ) {
 	# Complain if this option needs an argument.
 #	if ( $mand && !($type eq 's' ? defined($optarg) : 0) ) {
 	if ( $mand ) {
@@ -1088,7 +1088,7 @@ sub FindOption ($$$$$) {
     # Get key if this is a "name=value" pair for a hash option.
     my $key;
     if ($ctl->[CTL_DEST] == CTL_DEST_HASH && defined $arg) {
-	($key, $arg) = ($arg =~ /^([^=]*)=(.*)$/s) ? ($1, $2)
+	($key, $arg) = ($arg =~ m/^([^=]*)=(.*)$/s) ? ($1, $2)
 	  : ($arg, defined($ctl->[CTL_DEFAULT]) ? $ctl->[CTL_DEFAULT] :
 	     ($mand ? undef : ($type eq 's' ? "" : 1)));
 	if (! defined $arg) {
@@ -1119,7 +1119,7 @@ sub FindOption ($$$$$) {
 
 	# Check for option or option list terminator.
 	if ($arg eq $argend ||
-	    $arg =~ /^$prefix.+/) {
+	    $arg =~ m/^$prefix.+/) {
 	    # Push back.
 	    unshift (@$argv, $arg);
 	    # Supply empty value.
@@ -1134,15 +1134,15 @@ sub FindOption ($$$$$) {
 	my $o_valid = $type eq 'o' ? PAT_XINT : PAT_INT;
 
 	if ( $bundling && defined $rest
-	     && $rest =~ /^($key_valid)($o_valid)(.*)$/si ) {
+	     && $rest =~ m/^($key_valid)($o_valid)(.*)$/si ) {
 	    ($key, $arg, $rest) = ($1, $2, $+);
 	    chop($key) if $key;
-	    $arg = ($type eq 'o' && $arg =~ /^0/) ? oct($arg) : 0+$arg;
+	    $arg = ($type eq 'o' && $arg =~ m/^0/) ? oct($arg) : 0+$arg;
 	    unshift (@$argv, $starter.$rest) if defined $rest && $rest ne '';
 	}
-	elsif ( $arg =~ /^$o_valid$/si ) {
+	elsif ( $arg =~ m/^$o_valid$/si ) {
 	    $arg =~ tr/_//d;
-	    $arg = ($type eq 'o' && $arg =~ /^0/) ? oct($arg) : 0+$arg;
+	    $arg = ($type eq 'o' && $arg =~ m/^0/) ? oct($arg) : 0+$arg;
 	}
 	else {
 	    if ( defined $optarg || $mand ) {
@@ -1181,13 +1181,13 @@ sub FindOption ($$$$$) {
 	# [-]NN[.NN][eNN]
 	my $o_valid = PAT_FLOAT;
 	if ( $bundling && defined $rest &&
-	     $rest =~ /^($key_valid)($o_valid)(.*)$/s ) {
+	     $rest =~ m/^($key_valid)($o_valid)(.*)$/s ) {
 	    $arg =~ tr/_//d;
 	    ($key, $arg, $rest) = ($1, $2, $+);
 	    chop($key) if $key;
 	    unshift (@$argv, $starter.$rest) if defined $rest && $rest ne '';
 	}
-	elsif ( $arg =~ /^$o_valid$/ ) {
+	elsif ( $arg =~ m/^$o_valid$/ ) {
 	    $arg =~ tr/_//d;
 	}
 	else {
@@ -1222,7 +1222,7 @@ sub ValidValue ($$$$$) {
     my ($ctl, $arg, $mand, $argend, $prefix) = @_;
 
     if ( $ctl->[CTL_DEST] == CTL_DEST_HASH ) {
-	return 0 unless $arg =~ /[^=]+=(.*)/;
+	return 0 unless $arg =~ m/[^=]+=(.*)/;
 	$arg = $1;
     }
 
@@ -1235,7 +1235,7 @@ sub ValidValue ($$$$$) {
 	return (1) if $arg eq "-";
 
 	# Check for option or option list terminator.
-	return 0 if $arg eq $argend || $arg =~ /^$prefix.+/;
+	return 0 if $arg eq $argend || $arg =~ m/^$prefix.+/;
 	return 1;
     }
 
@@ -1244,7 +1244,7 @@ sub ValidValue ($$$$$) {
 	    || $type eq 'o' ) { # dec/oct/hex/bin value
 
 	my $o_valid = $type eq 'o' ? PAT_XINT : PAT_INT;
-	return $arg =~ /^$o_valid$/si;
+	return $arg =~ m/^$o_valid$/si;
     }
 
     elsif ( $type eq 'f' ) { # real number, int is also ok
@@ -1252,7 +1252,7 @@ sub ValidValue ($$$$$) {
 	# and at least one digit following the point and 'e'.
 	# [-]NN[.NN][eNN]
 	my $o_valid = PAT_FLOAT;
-	return $arg =~ /^$o_valid$/;
+	return $arg =~ m/^$o_valid$/;
     }
     die("ValidValue: Cannot happen\n");
 }
@@ -1278,7 +1278,7 @@ sub Configure (@) {
     foreach $opt ( @options ) {
 	my $try = lc ($opt);
 	my $action = 1;
-	if ( $try =~ /^no_?(.*)$/s ) {
+	if ( $try =~ m/^no_?(.*)$/s ) {
 	    $action = 0;
 	    $try = $+;
 	}
@@ -1309,10 +1309,10 @@ sub Configure (@) {
 	elsif ( $try eq 'gnu_compat' ) {
 	    $gnu_compat = $action;
 	}
-	elsif ( $try =~ /^(auto_?)?version$/ ) {
+	elsif ( $try =~ m/^(auto_?)?version$/ ) {
 	    $auto_version = $action;
 	}
-	elsif ( $try =~ /^(auto_?)?help$/ ) {
+	elsif ( $try =~ m/^(auto_?)?help$/ ) {
 	    $auto_help = $action;
 	}
 	elsif ( $try eq 'ignorecase' or $try eq 'ignore_case' ) {
@@ -1336,26 +1336,26 @@ sub Configure (@) {
 	elsif ( $try eq 'pass_through' or $try eq 'passthrough' ) {
 	    $passthrough = $action;
 	}
-	elsif ( $try =~ /^prefix=(.+)$/ && $action ) {
+	elsif ( $try =~ m/^prefix=(.+)$/ && $action ) {
 	    $genprefix = $1;
 	    # Turn into regexp. Needs to be parenthesized!
 	    $genprefix = "(" . quotemeta($genprefix) . ")";
-	    eval { '' =~ /$genprefix/; };
+	    eval { '' =~ m/$genprefix/; };
 	    die("Getopt::Long: invalid pattern \"$genprefix\"") if $@;
 	}
-	elsif ( $try =~ /^prefix_pattern=(.+)$/ && $action ) {
+	elsif ( $try =~ m/^prefix_pattern=(.+)$/ && $action ) {
 	    $genprefix = $1;
 	    # Parenthesize if needed.
 	    $genprefix = "(" . $genprefix . ")"
-	      unless $genprefix =~ /^\(.*\)$/;
+	      unless $genprefix =~ m/^\(.*\)$/;
 	    eval { '' =~ m"$genprefix"; };
 	    die("Getopt::Long: invalid pattern \"$genprefix\"") if $@;
 	}
-	elsif ( $try =~ /^long_prefix_pattern=(.+)$/ && $action ) {
+	elsif ( $try =~ m/^long_prefix_pattern=(.+)$/ && $action ) {
 	    $longprefix = $1;
 	    # Parenthesize if needed.
 	    $longprefix = "(" . $longprefix . ")"
-	      unless $longprefix =~ /^\(.*\)$/;
+	      unless $longprefix =~ m/^\(.*\)$/;
 	    eval { '' =~ m"$longprefix"; };
 	    die("Getopt::Long: invalid long prefix pattern \"$longprefix\"") if $@;
 	}
@@ -1388,7 +1388,7 @@ sub VersionMessage(@) {
 
     my $v = $main::VERSION;
     my $fh = $pa->{-output} ||
-      ($pa->{-exitval} eq "NOEXIT" || $pa->{-exitval} < 2) ? \*STDOUT : \*STDERR;
+      ($pa->{-exitval} eq "NOEXIT" || $pa->{-exitval} +< 2) ? \*STDOUT : \*STDERR;
 
     print $fh (defined($pa->{-message}) ? $pa->{-message} : (),
 	       $0, defined $v ? " version $v" : (),
@@ -1397,8 +1397,7 @@ sub VersionMessage(@) {
 	       " version ",
 	       defined($Getopt::Long::VERSION_STRING)
 	         ? $Getopt::Long::VERSION_STRING : $VERSION, ";",
-	       " Perl version ",
-	       $] >= 5.006 ? sprintf("%vd", $^V) : $],
+	       " Perl version $^V",
 	       ")\n");
     exit($pa->{-exitval}) unless $pa->{-exitval} eq "NOEXIT";
 }
@@ -1433,7 +1432,7 @@ sub setup_pa_args($@) {
     @_ = () if @_ == 2 && $_[0] eq $tag;
 
     my $pa;
-    if ( @_ > 1 ) {
+    if ( @_ +> 1 ) {
 	$pa = { @_ };
     }
     else {
@@ -1448,7 +1447,7 @@ sub setup_pa_args($@) {
 	$pa->{-message} = $pa->{-msg};
 	delete($pa->{-msg});
     }
-    elsif ( $pa =~ /^-?\d+$/ ) {
+    elsif ( $pa =~ m/^-?\d+$/ ) {
 	$pa = { -exitval => $pa };
     }
     else {
