@@ -6,7 +6,7 @@ use strict;
 use vars qw( @ISA $VERSION $MATCH_SUPERS $USING_LANGUAGE_TAGS
              $USE_LITERALS $MATCH_SUPERS_TIGHTLY);
 use Carp ();
-use I18N::LangTags 0.30 ();
+use I18N::LangTags v0.30 ();
 
 #--------------------------------------------------------------------------
 
@@ -35,7 +35,7 @@ sub quant {
   my($handle, $num, @forms) = @_;
 
   return $num if @forms == 0; # what should this mean?
-  return $forms[2] if @forms > 2 and $num == 0; # special zeroth case
+  return $forms[2] if @forms +> 2 and $num == 0; # special zeroth case
 
   # Normal case:
   # Note that the formatting of $num is preserved.
@@ -61,7 +61,7 @@ sub numerate {
 
 sub numf {
   my($handle, $num) = @_[0,1];
-  if($num < 10_000_000_000 and $num > -10_000_000_000 and $num == int($num)) {
+  if($num +< 10_000_000_000 and $num +> -10_000_000_000 and $num == int($num)) {
     $num += 0;  # Just use normal integer stringification.
          # Specifically, don't let %G turn ten million into 1E+007
   } else {
@@ -170,7 +170,7 @@ sub init { return } # no-op
 
 sub maketext {
   # Remember, this can fail.  Failure is controllable many ways.
-  Carp::croak "maketext requires at least one parameter" unless @_ > 1;
+  Carp::croak "maketext requires at least one parameter" unless @_ +> 1;
 
   my($handle, $phrase) = splice(@_,0,2);
 
@@ -198,7 +198,7 @@ sub maketext {
       $value = $h_r->{$phrase} = $handle->_compile($phrase);
       last;
     }
-    print "  Not found in $h_r, nor automakable\n" if DEBUG > 1;
+    print "  Not found in $h_r, nor automakable\n" if DEBUG +> 1;
     # else keep looking
   }
 
@@ -398,7 +398,7 @@ sub _try_use {   # Basically a wrapper around "require Modulename"
     eval "require $module"; # used to be "use $module", but no point in that.
   }
   if($@) {
-    print "Error using $module \: $@\n" if DEBUG > 1;
+    print "Error using $module \: $@\n" if DEBUG +> 1;
     return $tried{$module} = 0;
   } else {
     print " OK, $module is used\n" if DEBUG;
@@ -412,7 +412,7 @@ sub _lex_refs {  # report the lexicon references for this handle's class
   # returns an arrayREF!
   no strict 'refs';
   my $class = ref($_[0]) || $_[0];
-  print "Lex refs lookup on $class\n" if DEBUG > 1;
+  print "Lex refs lookup on $class\n" if DEBUG +> 1;
   return $isa_scan{$class} if exists $isa_scan{$class};  # memoization!
 
   my @lex_refs;
