@@ -46,7 +46,7 @@ sub getnetbyaddr ($;$) {
 } 
 
 sub getnet($) {
-    if ($_[0] =~ /^\d+(?:\.\d+(?:\.\d+(?:\.\d+)?)?)?$/) {
+    if ($_[0] =~ m/^\d+(?:\.\d+(?:\.\d+(?:\.\d+)?)?)?$/) {
 	require Socket;
 	&getnetbyaddr(Socket::inet_aton(shift));
     } else {
