@@ -363,6 +363,7 @@ my %VALID_COMMANDS = (
     'for'    =>  1,
     'begin'  =>  1,
     'end'    =>  1,
+    'encoding' => '1',
 );
 
 my %VALID_SEQUENCES = (
@@ -638,7 +639,7 @@ Set (if argument specified) and retrieve the number of errors found.
 =cut
 
 sub num_errors {
-   return (@_ > 1) ? ($_[0]->{_NUM_ERRORS} = $_[1]) : $_[0]->{_NUM_ERRORS};
+   return (@_ +> 1) ? ($_[0]->{_NUM_ERRORS} = $_[1]) : $_[0]->{_NUM_ERRORS};
 }
 
 ##################################
@@ -650,7 +651,7 @@ Set (if argument specified) and retrieve the number of warnings found.
 =cut
 
 sub num_warnings {
-   return (@_ > 1) ? ($_[0]->{_NUM_WARNINGS} = $_[1]) : $_[0]->{_NUM_WARNINGS};
+   return (@_ +> 1) ? ($_[0]->{_NUM_WARNINGS} = $_[1]) : $_[0]->{_NUM_WARNINGS};
 }
 
 ##################################
@@ -663,7 +664,7 @@ found in the C<=head1 NAME> section.
 =cut
 
 sub name {
-    return (@_ > 1 && $_[1]) ?
+    return (@_ +> 1 && $_[1]) ?
         ($_[0]->{-name} = $_[1]) : $_[0]->{-name};  
 }
 
@@ -686,7 +687,7 @@ sub node {
         # add node, order important!
         push(@{$self->{_nodes}}, $text);
         # keep also a uniqueness counter
-        $self->{_unique_nodes}->{$text}++ if($text !~ /^\s*$/s);
+        $self->{_unique_nodes}->{$text}++ if($text !~ m/^\s*$/s);
         return $text;
     }
     @{$self->{_nodes}};
@@ -711,7 +712,7 @@ sub idx {
         # add node, order important!
         push(@{$self->{_index}}, $text);
         # keep also a uniqueness counter
-        $self->{_unique_nodes}->{$text}++ if($text !~ /^\s*$/s);
+        $self->{_unique_nodes}->{$text}++ if($text !~ m/^\s*$/s);
         return $text;
     }
     @{$self->{_index}};
@@ -762,7 +763,7 @@ sub end_pod {
     my %nodes;
     foreach($self->node()) {
         $nodes{$_} = 1;
-        if(/^(\S+)\s+\S/) {
+        if(m/^(\S+)\s+\S/) {
             # we have more than one word. Use the first as a node, too.
             # This is used heavily in perlfunc.pod
             $nodes{$1} ||= 2; # derived node
@@ -788,8 +789,8 @@ sub end_pod {
 
     # check the internal nodes for uniqueness. This pertains to
     # =headX, =item and X<...>
-    if($self->{-warnings} && $self->{-warnings}>1) {
-      foreach(grep($self->{_unique_nodes}->{$_} > 1,
+    if($self->{-warnings} && $self->{-warnings}+>1) {
+      foreach(grep($self->{_unique_nodes}->{$_} +> 1,
         keys %{$self->{_unique_nodes}})) {
           $self->poderror({ -line => '-', -file => $infile,
             -severity => 'WARNING',
@@ -826,7 +827,7 @@ sub command {
             # check for argument
             $arg = $self->interpolate_and_check($paragraph, $line,$file);
             my $indent = 4; # default
-            if($arg && $arg =~ /^\s*(\d+)\s*$/) {
+            if($arg && $arg =~ m/^\s*(\d+)\s*$/) {
                 $indent = $1;
             }
             # start a new list
@@ -857,15 +858,15 @@ sub command {
             }
             # check for argument
             $arg = $self->interpolate_and_check($paragraph, $line, $file);
-            if($arg && $arg =~ /(\S+)/) {
+            if($arg && $arg =~ m/(\S+)/) {
                 $arg =~ s/[\s\n]+$//;
                 my $type;
-                if($arg =~ /^[*]\s*(\S*.*)/) {
+                if($arg =~ m/^[*]\s*(\S*.*)/) {
                   $type = 'bullet';
                   $self->{_list_item_contents} = $1 ? 1 : 0;
                   $arg = $1;
                 }
-                elsif($arg =~ /^\d+\.?\s*(\S*)/) {
+                elsif($arg =~ m/^\d+\.?\s*(\S*)/) {
                   $type = 'number';
                   $self->{_list_item_contents} = $1 ? 1 : 0;
                   $arg = $1;
@@ -906,7 +907,7 @@ sub command {
             else {
                 # check for spurious characters
                 $arg = $self->interpolate_and_check($paragraph, $line,$file);
-                if($arg && $arg =~ /\S/) {
+                if($arg && $arg =~ m/\S/) {
                     $self->poderror({ -line => $line, -file => $file,
                          -severity => 'ERROR', 
                          -msg => "Spurious character(s) after =back" });
@@ -922,10 +923,10 @@ sub command {
                 }
             }
         }
-        elsif($cmd =~ /^head(\d+)/) {
+        elsif($cmd =~ m/^head(\d+)/) {
             my $hnum = $1;
             $self->{"_have_head_$hnum"}++; # count head types
-            if($hnum > 1 && !$self->{"_have_head_".($hnum -1)}) {
+            if($hnum +> 1 && !$self->{"_have_head_".($hnum -1)}) {
               $self->poderror({ -line => $line, -file => $file,
                    -severity => 'WARNING', 
                    -msg => "=head$hnum without preceding higher level"});
@@ -934,7 +935,7 @@ sub command {
             if(defined $self->{_commands_in_head} &&
               $self->{_commands_in_head} == 0 &&
               defined $self->{_last_head} &&
-              $self->{_last_head} >= $hnum) {
+              $self->{_last_head} +>= $hnum) {
                 $self->poderror({ -line => $line, -file => $file,
                      -severity => 'WARNING', 
                      -msg => "empty section in previous paragraph"});
@@ -978,7 +979,7 @@ sub command {
             else {
                 # check for argument
                 $arg = $self->interpolate_and_check($paragraph, $line,$file);
-                unless($arg && $arg =~ /(\S+)/) {
+                unless($arg && $arg =~ m/(\S+)/) {
                     $self->poderror({ -line => $line, -file => $file,
                          -severity => 'ERROR', 
                          -msg => "No argument for =begin"});
@@ -1008,17 +1009,17 @@ sub command {
             }
         }
         elsif($cmd eq 'for') {
-            unless($paragraph =~ /\s*(\S+)\s*/) {
+            unless($paragraph =~ m/\s*(\S+)\s*/) {
                 $self->poderror({ -line => $line, -file => $file,
                      -severity => 'ERROR', 
                      -msg => "=for without formatter specification" });
             }
             $arg = ''; # do not expand paragraph below
         }
-        elsif($cmd =~ /^(pod|cut)$/) {
+        elsif($cmd =~ m/^(pod|cut)$/) {
             # check for argument
             $arg = $self->interpolate_and_check($paragraph, $line,$file);
-            if($arg && $arg =~ /(\S+)/) {
+            if($arg && $arg =~ m/(\S+)/) {
                 $self->poderror({ -line => $line, -file => $file,
                       -severity => 'ERROR', 
                       -msg => "Spurious text after =$cmd"});
@@ -1076,7 +1077,7 @@ sub _check_ptree {
         unless(ref) {
             # count the unescaped angle brackets
             # complain only when warning level is greater than 1
-            if($self->{-warnings} && $self->{-warnings}>1) {
+            if($self->{-warnings} && $self->{-warnings}+>1) {
               my $count;
               if($count = tr/<>/<>/) {
                 $self->poderror({ -line => $line, -file => $file,
@@ -1100,7 +1101,7 @@ sub _check_ptree {
             $text .= $self->_check_ptree($contents, $line, $file, "$nestlist$cmd");
             next;
         }
-        if($nestlist =~ /$cmd/) {
+        if($nestlist =~ m/$cmd/) {
             $self->poderror({ -line => $line, -file => $file,
                  -severity => 'WARNING', 
                  -msg => "nested commands $cmd<...$cmd<...>...>"});
@@ -1109,7 +1110,7 @@ sub _check_ptree {
         }
         if($cmd eq 'E') {
             # preserve entities
-            if(@$contents > 1 || ref $$contents[0] || $$contents[0] !~ /^\w+$/) {
+            if(@$contents +> 1 || ref $$contents[0] || $$contents[0] !~ m/^\w+$/) {
                 $self->poderror({ -line => $line, -file => $file,
                     -severity => 'ERROR', 
                     -msg => "garbled entity " . $_->raw_text()});
@@ -1117,20 +1118,20 @@ sub _check_ptree {
             }
             my $ent = $$contents[0];
             my $val;
-            if($ent =~ /^0x[0-9a-f]+$/i) {
+            if($ent =~ m/^0x[0-9a-f]+$/i) {
                 # hexadec entity
                 $val = hex($ent);
             }
-            elsif($ent =~ /^0\d+$/) {
+            elsif($ent =~ m/^0\d+$/) {
                 # octal
                 $val = oct($ent);
             }
-            elsif($ent =~ /^\d+$/) {
+            elsif($ent =~ m/^\d+$/) {
                 # numeric entity
                 $val = $ent;
             }
             if(defined $val) {
-                if($val>0 && $val<256) {
+                if($val+>0 && $val+<256) {
                     $text .= chr($val);
                 }
                 else {
@@ -1173,7 +1174,7 @@ sub _check_ptree {
             # remember link
             $self->hyperlink([$line,$link]);
         }
-        elsif($cmd =~ /[BCFIS]/) {
+        elsif($cmd =~ m/[BCFIS]/) {
             # add the guts
             $text .= $self->_check_ptree($contents, $line, $file, "$nestlist$cmd");
         }
@@ -1186,7 +1187,7 @@ sub _check_ptree {
         }
         elsif($cmd eq 'X') {
             my $idx = $self->_check_ptree($contents, $line, $file, "$nestlist$cmd");
-            if($idx =~ /^\s*$/s) {
+            if($idx =~ m/^\s*$/s) {
                 $self->poderror({ -line => $line, -file => $file,
                     -severity => 'ERROR', 
                     -msg => "Empty X<>"});
@@ -1230,7 +1231,7 @@ sub textblock {
     unless($self->{_have_begin}) {
         my $block = $self->interpolate_and_check($paragraph, $line,$file);
         if($self->{_current_head1} eq 'NAME') {
-            if($block =~ /^\s*(\S+?)\s*[,-]/) {
+            if($block =~ m/^\s*(\S+?)\s*[,-]/) {
                 # this is the canonical name
                 $self->{-name} = $1 unless(defined $self->{-name});
             }
