@@ -15,7 +15,7 @@ BEGIN { *DEBUG = defined(&Pod::Simple::DEBUG)
           : sub() {0}
       }
 
-use Text::Wrap 98.112902 ();
+use Text::Wrap v98.112902 ();
 $Text::Wrap::wrap = 'overflow';
 #~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
@@ -74,9 +74,9 @@ sub emit_par {
   my $indent = ' ' x ( 2 * $self->{'Indent'} + 4 + ($tweak_indent||0) );
    # Yes, 'STRING' x NEGATIVE gives '', same as 'STRING' x 0
 
-  $self->{'Thispara'} =~ tr{\xAD}{}d if Pod::Simple::ASCII;
+  $self->{'Thispara'} =~ tr{\x{AD}}{}d if Pod::Simple::ASCII;
   my $out = Text::Wrap::wrap($indent, $indent, $self->{'Thispara'} .= "\n");
-  $out =~ tr{\xA0}{ } if Pod::Simple::ASCII;
+  $out =~ tr{\x{A0}}{ } if Pod::Simple::ASCII;
   print {$self->{'output_fh'}} $out, "\n";
   $self->{'Thispara'} = '';
   
@@ -88,8 +88,8 @@ sub emit_par {
 sub end_Verbatim  {
   my $self = shift;
   if(Pod::Simple::ASCII) {
-    $self->{'Thispara'} =~ tr{\xA0}{ };
-    $self->{'Thispara'} =~ tr{\xAD}{}d;
+    $self->{'Thispara'} =~ tr{\x{A0}}{ };
+    $self->{'Thispara'} =~ tr{\x{AD}}{}d;
   }
 
   my $i = ' ' x ( 2 * $self->{'Indent'} + 4);
