@@ -131,16 +131,17 @@ sub ungensym ($) {}
 
 sub qualify ($;$) {
     my ($name) = @_;
+    ref \$name eq "GLOB" and Carp::confess("glob..." . ref $name);
     if (!ref($name) && index($name, '::') == -1 && index($name, "'") == -1) {
 	my $pkg;
 	# Global names: special character, "^xyz", or other. 
-	if ($name =~ /^(([^a-z])|(\^[a-z_]+))\z/i || $global{$name}) {
+	if ($name =~ m/^(([^a-z])|(\^[a-z_]+))\z/i || $global{$name}) {
 	    # RGS 2001-11-05 : translate leading ^X to control-char
-	    $name =~ s/^\^([a-z_])/'qq(\c'.$1.')'/eei;
+	    $name =~ s/^\^([a-z_])/{eval 'qq(\c'.$1.')'}/i;
 	    $pkg = "main";
 	}
 	else {
-	    $pkg = (@_ > 1) ? $_[1] : caller;
+	    $pkg = (@_ +> 1) ? $_[1] : caller;
 	}
 	$name = $pkg . "::" . $name;
     }
@@ -148,7 +149,7 @@ sub qualify ($;$) {
 }
 
 sub qualify_to_ref ($) {
-    return \*{ Symbol::fetch_glob( qualify $_[0], @_ > 1 ? $_[1] : caller ) };
+    return \*{ Symbol::fetch_glob( qualify $_[0], @_ +> 1 ? $_[1] : caller ) };
 }
 
 #
@@ -161,10 +162,10 @@ sub delete_package ($) {
 
     # expand to full symbol table name if needed
 
-    unless ($pkg =~ /^main::.*::$/) {
-        $pkg = "main$pkg"	if	$pkg =~ /^::/;
-        $pkg = "main::$pkg"	unless	$pkg =~ /^main::/;
-        $pkg .= '::'		unless	$pkg =~ /::$/;
+    unless ($pkg =~ m/^main::.*::$/) {
+        $pkg = "main$pkg"	if	$pkg =~ m/^::/;
+        $pkg = "main::$pkg"	unless	$pkg =~ m/^main::/;
+        $pkg .= '::'		unless	$pkg =~ m/::$/;
     }
 
     my($stem, $leaf) = $pkg =~ m/(.*::)(\w+::)$/;
