@@ -1,22 +1,19 @@
 package feature;
 
-our $VERSION = '1.10';
+our $VERSION = '1.11';
 
 # (feature name) => (internal name, used in %^H)
 my %feature = (
     switch => 'feature_switch',
-    say    => "feature_say",
-    err    => "feature_err",
     state  => "feature_state",
 );
 
 my %feature_bundle = (
-    "5.10.0" => [qw(switch say err state)],
+    "5.10.0" => [qw(switch state)],
 );
+
 # latest version here
-# keep it harcoded until we actually bump the version number to 5.10
 $feature_bundle{"5.10"} = $feature_bundle{"5.10.0"};
-#$feature_bundle{"5.10"} = $feature_bundle{sprintf("%vd",$^V)};
 
 $feature_bundle{"5.9.5"} = $feature_bundle{"5.10.0"};
 
@@ -29,13 +26,13 @@ feature - Perl pragma to enable new syntactic features
 
 =head1 SYNOPSIS
 
-    use feature qw(switch say);
+    use feature qw(switch);
     given ($foo) {
-	when (1)	  { say "\$foo == 1" }
-	when ([2,3])	  { say "\$foo == 2 || \$foo == 3" }
-	when (/^a[bc]d$/) { say "\$foo eq 'abd' || \$foo eq 'acd'" }
-	when ($_ > 100)   { say "\$foo > 100" }
-	default		  { say "None of the above" }
+	when (1)	  { print "\$foo == 1" }
+	when ([2,3])	  { print "\$foo == 2 || \$foo == 3" }
+	when (/^a[bc]d$/) { print "\$foo eq 'abd' || \$foo eq 'acd'" }
+	when ($_ > 100)   { print "\$foo > 100" }
+	default		  { print "None of the above" }
     }
 
     use feature ':5.10'; # loads all features available in perl 5.10
@@ -82,21 +79,6 @@ given/when construct.
 
 See L<perlsyn/"Switch statements"> for details.
 
-=head2 The 'say' feature
-
-C<use feature 'say'> tells the compiler to enable the Perl 6
-C<say> function.
-
-See L<perlfunc/say> for details.
-
-=head2 the 'err' feature
-
-C<use feature 'err'> tells the compiler to enable the C<err>
-operator.
-
-C<err> is a low-precedence variant of the C<//> operator:
-see C<perlop> for details.
-
 =head2 the 'state' feature
 
 C<use feature 'state'> tells the compiler to enable C<state>
@@ -110,7 +92,7 @@ It's possible to load a whole slew of features in one go, using
 a I<feature bundle>. The name of a feature bundle is prefixed with
 a colon, to distinguish it from an actual feature. At present, the
 only feature bundles are C<use feature ":5.10"> and C<use feature ":5.10.0">,
-which both are equivalent to C<use feature qw(switch say err state)>.
+which both are equivalent to C<use feature qw(switch say state)>.
 
 In the forthcoming 5.10.X perl releases, C<use feature ":5.10"> will be
 equivalent to the latest C<use feature ":5.10.X">.
@@ -130,16 +112,22 @@ all available features in the main compilation unit (that is, the one-liner.)
 
 By requiring explicitly a minimal Perl version number for your program, with
 the C<use VERSION> construct, and when the version is higher than or equal to
-5.9.5. That is,
+5.10.0. That is,
 
-    use 5.9.5;
+    use 5.10.0;
 
 will do an implicit
 
-    use feature ':5.9.5';
+    use feature ':5.10.0';
 
 and so on.
 
+But to avoid portability warnings (see L<perlfunc/use>), you may prefer:
+
+    use 5.010;
+
+with the same effect.
+
 =back
 
 =cut
@@ -151,11 +139,12 @@ sub import {
     }
     while (@_) {
 	my $name = shift(@_);
-	if ($name =~ /^:(.*)/) {
-	    if (!exists $feature_bundle{$1}) {
-		unknown_feature_bundle($1);
+	if (substr($name, 0, 1) eq ":") {
+	    my $v = substr($name, 1);
+	    if (!exists $feature_bundle{$v}) {
+		unknown_feature_bundle($v);
 	    }
-	    unshift @_, @{$feature_bundle{$1}};
+	    unshift @_, @{$feature_bundle{$v}};
 	    next;
 	}
 	if (!exists $feature{$name}) {
@@ -176,11 +165,12 @@ sub unimport {
 
     while (@_) {
 	my $name = shift;
-	if ($name =~ /^:(.*)/) {
-	    if (!exists $feature_bundle{$1}) {
-		unknown_feature_bundle($1);
+	if (substr($name, 0, 1) eq ":") {
+	    my $v = substr($name, 1);
+	    if (!exists $feature_bundle{$v}) {
+		unknown_feature_bundle($v);
 	    }
-	    unshift @_, @{$feature_bundle{$1}};
+	    unshift @_, @{$feature_bundle{$v}};
 	    next;
 	}
 	if (!exists($feature{$name})) {
