@@ -36,21 +36,21 @@ else
 my $files = 0;
 foreach my $file (@w_files) {
 
-    next if $file =~ /(~|\.orig|,v)$/;
-    next if $file =~ /perlio$/ && !('PerlIO::Layer'->find( 'perlio'));
+    next if $file =~ m/(~|\.orig|,v)$/;
+    next if $file =~ m/perlio$/ && !('PerlIO::Layer'->find( 'perlio'));
     next if -d $file;
 
-    open F, "<$file" or die "Cannot open $file: $!\n" ;
+    open F, "<", "$file" or die "Cannot open $file: $!\n" ;
     my $line = 0;
-    while (<F>) {
+    while ( ~< *F) {
         $line++;
-	last if /^__END__/ ;
+	last if m/^__END__/ ;
     }
 
     {
         local $/ = undef;
         $files++;
-        @prgs = (@prgs, $file, split "\n########\n", <F>) ;
+        @prgs = (@prgs, $file, split "\n########\n", ~< *F) ;
     }
     close F ;
 }
@@ -59,10 +59,12 @@ undef $/;
 
 plan tests => (scalar(@prgs)-$files);
 
+my $file;
 for (@prgs){
-    unless (/\n/)
+    unless (m/\n/)
      {
       print "# From $_\n";
+      $file = $_;
       next;
      }
     my $switch = "";
@@ -71,7 +73,7 @@ for (@prgs){
     if (s/^\s*-\w+//){
         $switch = $&;
     }
-    my($prog,$expected) = split(/\nEXPECT(?:\n|$)/, $_, 2);
+    my($prog,$expected) = split(m/\nEXPECT(?:\n|$)/, $_, 2);
 
     my ($todo, $todo_reason);
     $todo = $prog =~ s/^#\s*TODO\s*(.*)\n//m and $todo_reason = $1;
@@ -84,13 +86,13 @@ for (@prgs){
 	}
 	$todo_reason = $temp;
     }
-    if ( $prog =~ /--FILE--/) {
-        my(@files) = split(/\n--FILE--\s*([^\s\n]*)\s*\n/, $prog) ;
+    if ( $prog =~ m/--FILE--/) {
+        my(@files) = split(m/\n--FILE--\s*([^\s\n]*)\s*\n/, $prog) ;
 	shift @files ;
 	die "Internal error: test $_ didn't split into pairs, got " .
 		scalar(@files) . "[" . join("%%%%", @files) ."]\n"
 	    if @files % 2 ;
-	while (@files > 2) {
+	while (@files +> 2) {
 	    my $filename = shift @files ;
 	    my $code = shift @files ;
     	    push @temps, $filename ;
@@ -98,7 +100,7 @@ for (@prgs){
                 mkpath($1);
                 push(@temp_path, $1);
     	    }
-	    open F, ">$filename" or die "Cannot open $filename: $!\n" ;
+	    open F, ">", "$filename" or die "Cannot open $filename: $!\n" ;
 	    print F $code ;
 	    close F or die "Cannot close $filename: $!\n";
 	}
@@ -112,10 +114,10 @@ for (@prgs){
 	$prog =~ s|"\."|":"|g;
     }
 
-    open TEST, ">$tmpfile" or die "Cannot open >$tmpfile: $!";
+    open TEST, ">", "$tmpfile" or die "Cannot open >$tmpfile: $!";
     print TEST q{
         BEGIN {
-            open(STDERR, ">&STDOUT")
+            open(STDERR, ">&", "STDOUT")
               or die "Can't dup STDOUT->STDERR: $!;";
         }
     };
@@ -165,7 +167,7 @@ for (@prgs){
 	}
     }
     die "$0: can't have OPTION regex and random\n"
-        if $option_regex + $option_random > 1;
+        if $option_regex + $option_random +> 1;
     my $ok = 0;
     if ($results =~ s/^SKIPPED\n//) {
 	print "$results\n" ;
@@ -175,16 +177,16 @@ for (@prgs){
         $ok = randomMatch($results, $expected);
     }
     elsif ($option_regex) {
-	$ok = $results =~ /^$expected/;
+	$ok = $results =~ m/^$expected/;
     }
     elsif ($prefix) {
-	$ok = $results =~ /^\Q$expected/;
+	$ok = $results =~ m/^\Q$expected/;
     }
     else {
 	$ok = $results eq $expected;
     }
  
-    print_err_line( $switch, $prog, $expected, $results, $todo ) unless $ok;
+    print_err_line( $switch, $prog, $expected, $results, $todo, $file ) unless $ok;
 
     our $TODO = $todo ? $todo_reason : 0;
     ok($ok);
@@ -209,7 +211,8 @@ sub randomMatch
 
 sub print_err_line {
     my($switch, $prog, $expected, $results, $todo) = @_;
-    my $err_line = "PROG: $switch\n$prog\n" .
+    my $err_line = "FILE: $file\n" .
+                   "PROG: $switch\n$prog\n" .
 		   "EXPECTED:\n$expected\n" .
 		   "GOT:\n$results\n";
     if ($todo) {
