@@ -7,10 +7,6 @@ use Test::More ;
 use CompTestUtils;
 
 BEGIN {
-    plan(skip_all => "oneshot needs Perl 5.005 or better - you have Perl $]" )
-        if $] < 5.005 ;
-
-
     # use Test::NoWarnings, if available
     my $extra = 0 ;
     $extra = 1
@@ -97,14 +93,10 @@ sub run
             
         SKIP:
         {
-            # Threaded 5.6.x seems to have a problem comparing filehandles.
             use Config;
 
-            skip 'Cannot compare filehandles with threaded $]', 2
-                if $] >= 5.006  && $] < 5.007 && $Config{useithreads};
-
             my $lex = LexFile->new( my $out_file) ;
-            open OUT, ">$out_file" ;
+            open OUT, ">", "$out_file" ;
             eval { $a = $Func->(\*OUT, \*OUT) ;} ;
             like $@, mkErr("^$TopType: input and output handle are identical"),
                 '  Input and Output handle are the same';
@@ -250,7 +242,7 @@ sub run
 
         # corrupt the compressed data
         #substr($out, -10, 10) = "x" x 10 ;
-        substr($out, int(length($out)/3), 10) = 'abcdeabcde';
+        substr($out, int(length($out)/3), 10, 'abcdeabcde');
 
         my $result;
         ok ! $FuncInverse->(\$out => \$result, Transparent => 0), "  $TopTypeInverse ok";
@@ -353,7 +345,7 @@ sub run
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
-                    my $of = 'IO::File'->new( ">>$out_file") ;
+                    my $of = 'IO::File'->new( "$out_file", ">>") ;
                     ok $of, "  Created output filehandle" ;
 
                     ok &$Func(\$buffer, $of, AutoClose => 1, Append => $append), '  Compressed ok' ;
@@ -391,7 +383,7 @@ sub run
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
-                    my $out = 'IO::File'->new( ">>$out_file") ;
+                    my $out = 'IO::File'->new( "$out_file", ">>") ;
 
                     ok &$Func($in_file, $out, AutoClose => 1, Append => $append), '  Compressed ok' ;
 
@@ -423,7 +415,7 @@ sub run
 
                     my $lex = LexFile->new(my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
-                    my $in = 'IO::File'->new( "<$in_file") ;
+                    my $in = 'IO::File'->new( "$in_file", "<") ;
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
@@ -443,11 +435,11 @@ sub run
 
                     my $lex = LexFile->new(my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
-                    my $in = 'IO::File'->new( "<$in_file") ;
+                    my $in = 'IO::File'->new( "$in_file", "<") ;
 
                     ok ! -e $out_file, "  Output file does not exist";
                     writeFile($out_file, $already);
-                    my $out = 'IO::File'->new( ">>$out_file") ;
+                    my $out = 'IO::File'->new( "$out_file", ">>") ;
 
                     ok &$Func($in, $out, AutoClose => 1, Append => $append), '  Compressed ok' ;
 
@@ -463,7 +455,7 @@ sub run
 
                     my $lex = LexFile->new(my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
-                    my $in = 'IO::File'->new( "<$in_file") ;
+                    my $in = 'IO::File'->new( "$in_file", "<") ;
 
                     my $out = $already ;
 
@@ -481,16 +473,16 @@ sub run
                     my $lex = LexFile->new(my $in_file, my $out_file) ;
                     writeFile($in_file, $buffer);
 
-                       open(SAVEIN, "<&STDIN");
+                       open(SAVEIN, "<&", \*STDIN);
                     my $dummy = fileno SAVEIN ;
-                    ok open(STDIN, "<$in_file"), "  redirect STDIN";
+                    ok open(STDIN, "<", "$in_file"), "  redirect STDIN";
 
                     my $out = $already;
 
                     ok &$Func('-', \$out, Append => $append), '  Compressed ok' 
                         or diag $$Error ;
 
-                       open(STDIN, "<&SAVEIN");
+                       open(STDIN, "<&", \*SAVEIN);
 
                     my $got = anyUncompress(\$out, $already);
                     $got = undef if ! defined $buffer && $got eq '' ;
@@ -515,7 +507,7 @@ sub run
 
         writeFile($file1, "data1");
         writeFile($file2, "data2");
-        my $of = 'IO::File'->new( "<$file1") ;
+        my $of = 'IO::File'->new( "$file1", "<") ;
         ok $of, "  Created output filehandle" ;
 
         #my @input = (   undef, "", $file2, \undef, \'', \"abcde", $of) ;
@@ -554,7 +546,7 @@ sub run
                 title "$TopType - From Array Ref to Buffer, MultiStream $ms" ;
 
                 # rewind the filehandle
-                $of->open("<$file1") ;
+                $of->open("$file1", "<") ;
 
                 my $output  ;
                 ok &$Func(\@input, \$output, MultiStream => $ms, AutoClose => 0), '  Compressed ok' 
@@ -573,7 +565,7 @@ sub run
                 my $lex = LexFile->new( my $file3) ;
 
                 # rewind the filehandle
-                $of->open("<$file1") ;
+                $of->open("$file1", "<") ;
 
                 my $output  ;
                 ok &$Func(\@input, $file3, MultiStream => $ms, AutoClose => 0), '  Compressed ok' ;
@@ -590,10 +582,10 @@ sub run
 
                 my $lex = LexFile->new(my $file3) ;
 
-                my $fh3 = 'IO::File'->new( ">$file3");
+                my $fh3 = 'IO::File'->new( "$file3", ">");
 
                 # rewind the filehandle
-                $of->open("<$file1") ;
+                $of->open("$file1", "<") ;
 
                 my $output  ;
                 ok &$Func(\@input, $fh3, MultiStream => $ms, AutoClose => 0), '  Compressed ok' ;
@@ -644,7 +636,7 @@ sub run
             {
                 writeFile($name, $compressed);
 
-                $input = 'IO::File'->new( "<$name") ;
+                $input = 'IO::File'->new( "$name", "<") ;
             }
 
             my $trailing;
@@ -950,7 +942,7 @@ sub run
 
                     my $filename = "abcde";
                     my $lex = LexFile->new($filename) ;
-                    my $fh = 'IO::File'->new( ">$filename");
+                    my $fh = 'IO::File'->new( "$filename", ">");
                     
                     ok &$Func("<$tmpDir1/a*.tmp>" => $fh, 
                               MultiStream => $ms, AutoClose => 1), '  Compressed ok' 
@@ -1046,11 +1038,11 @@ sub run
                 my $of ;
                 if ($append) {
                     writeFile($out_file, $incumbent) ;
-                    $of = 'IO::File'->new( "+< $out_file") ;
+                    $of = 'IO::File'->new( "$out_file", "+<") ;
                 }
                 else {
                     ok ! -e $out_file, "  Output file does not exist" ;
-                    $of = 'IO::File'->new( "> $out_file") ;
+                    $of = 'IO::File'->new( "$out_file", ">") ;
                 }
                 isa_ok $of, 'IO::File', '  $of' ;
 
@@ -1090,11 +1082,11 @@ sub run
                 my $out ;
                 if ($append) {
                     writeFile($out_file, $incumbent) ;
-                    $out = 'IO::File'->new( "+< $out_file") ;
+                    $out = 'IO::File'->new( "$out_file", "+<") ;
                 }
                 else {
                     ok ! -e $out_file, "  Output file does not exist" ;
-                    $out = 'IO::File'->new( "> $out_file") ;
+                    $out = 'IO::File'->new( "$out_file", ">") ;
                 }
                 isa_ok $out, 'IO::File', '  $out' ;
 
@@ -1134,7 +1126,7 @@ sub run
                   { ok ! -e $out_file, "  Output file does not exist" }
 
                 writeFile($in_file, $comp);
-                my $in = 'IO::File'->new( "<$in_file") ;
+                my $in = 'IO::File'->new( "$in_file", "<") ;
 
                 ok &$Func($in, $out_file, Append => $append, @opts), '  Uncompressed ok' ;
 
@@ -1152,16 +1144,16 @@ sub run
                 my $out ;
                 if ($append) {
                     writeFile($out_file, $incumbent) ;
-                    $out = 'IO::File'->new( "+< $out_file") ;
+                    $out = 'IO::File'->new( "$out_file", "+<") ;
                 }
                 else {
                     ok ! -e $out_file, "  Output file does not exist" ;
-                    $out = 'IO::File'->new( "> $out_file") ;
+                    $out = 'IO::File'->new( "$out_file", ">") ;
                 }
                 isa_ok $out, 'IO::File', '  $out' ;
 
                 writeFile($in_file, $comp);
-                my $in = 'IO::File'->new( "<$in_file") ;
+                my $in = 'IO::File'->new( "$in_file", "<") ;
 
                 ok &$Func($in, $out, Append => $append, AutoClose => 1, @opts), '  Uncompressed ok' ;
 
@@ -1177,7 +1169,7 @@ sub run
 
                 my $lex = LexFile->new(my $in_file) ;
                 writeFile($in_file, $comp);
-                my $in = 'IO::File'->new( "<$in_file") ;
+                my $in = 'IO::File'->new( "$in_file", "<") ;
 
                 my $output ;
                 $output = $incumbent if $append ;
@@ -1194,9 +1186,9 @@ sub run
                 my $lex = LexFile->new(my $in_file) ;
                 writeFile($in_file, $comp);
 
-                   open(SAVEIN, "<&STDIN");
+                open(SAVEIN, "<&", \*STDIN);
                 my $dummy = fileno SAVEIN ;
-                ok open(STDIN, "<$in_file"), "  redirect STDIN";
+                ok open(STDIN, "<", "$in_file"), "  redirect STDIN";
 
                 my $output ;
                 $output = $incumbent if $append ;
@@ -1204,7 +1196,7 @@ sub run
                 ok &$Func('-', \$output, Append => $append, @opts), '  Uncompressed ok' 
                     or diag $$Error ;
 
-                   open(STDIN, "<&SAVEIN");
+                open(STDIN, "<&", \*SAVEIN);
 
                 is $keep_comp, $comp, "  Input buffer not changed" ;
                 is $output, $expected, "  Uncompressed matches original";
@@ -1221,7 +1213,7 @@ sub run
             my $appended = 'appended';
             my $len_appended = length $appended;
             writeFile($in_file, $comp . $appended . $comp . $appended) ;
-            my $in = 'IO::File'->new( "<$in_file") ;
+            my $in = 'IO::File'->new( "$in_file", "<") ;
 
             ok &$Func($in, \$out, Transparent => 0, InputLength => length $comp, @opts), '  Uncompressed ok' ;
 
@@ -1243,7 +1235,7 @@ sub run
 
         for my $stdin ('-', *STDIN) # , \*STDIN)
         {
-            title "$TopType - From stdin (via $stdin) to Buffer content, InputLength" ;
+            title "$TopType - From stdin to Buffer content, InputLength" ;
 
             my $lex = LexFile->new( my $in_file) ;
             my $expected = $buffer ;
@@ -1251,9 +1243,9 @@ sub run
             my $len_appended = length $appended;
             writeFile($in_file, $comp . $appended ) ;
 
-               open(SAVEIN, "<&STDIN");
+               open(SAVEIN, "<&", \*STDIN);
             my $dummy = fileno SAVEIN ;
-            ok open(STDIN, "<$in_file"), "  redirect STDIN";
+            ok open(STDIN, "<", "$in_file"), "  redirect STDIN";
 
             my $output ;
 
@@ -1266,7 +1258,7 @@ sub run
             is $output, $expected, "  Uncompressed matches original";
             is $buff, $appended, "  Appended data ok";
 
-              open(STDIN, "<&SAVEIN");
+              open(STDIN, "<&", \*SAVEIN);
         }
     }
 
@@ -1299,7 +1291,7 @@ sub run
         writeFile($file1, compressBuffer(getTopFuncName($UncompressClass),"data1"));
         writeFile($file2, compressBuffer(getTopFuncName($UncompressClass),"data2"));
 
-        my $of = 'IO::File'->new( "<$file1") ;
+        my $of = 'IO::File'->new( "$file1", "<") ;
         ok $of, "  Created output filehandle" ;
 
         #my @input    = ($file2, \$undef, \$null, \$comp, $of) ;
@@ -1322,7 +1314,7 @@ sub run
             title "$TopType - From ArrayRef to Filename" ;
 
             my $lex = LexFile->new( my $output);
-            $of->open("<$file1") ;
+            $of->open("$file1", "<") ;
 
             ok &$Func(\@input, $output, AutoClose => 0, @opts), '  UnCompressed ok' ;
 
@@ -1333,8 +1325,8 @@ sub run
             title "$TopType - From ArrayRef to Filehandle" ;
 
             my $lex = LexFile->new( my $output);
-            my $fh = 'IO::File'->new( ">$output") ;
-            $of->open("<$file1") ;
+            my $fh = 'IO::File'->new( "$output", ">") ;
+            $of->open("$file1", "<") ;
 
             ok &$Func(\@input, $fh, AutoClose => 0, @opts), '  UnCompressed ok' ;
             $fh->close;
@@ -1346,7 +1338,7 @@ sub run
             title "$TopType - From Array Ref to Array Ref" ;
 
             my @output = (\'first') ;
-            $of->open("<$file1") ;
+            $of->open("$file1", '<') ;
             ok &$Func(\@input, \@output, AutoClose => 0, @opts), '  UnCompressed ok' ;
 
             is_deeply \@input, \@keep, "  Input array not changed" ;
@@ -1445,7 +1437,7 @@ sub run
 
             my $output = 'abc' ;
             my $lex = LexFile->new( $output) ;
-            my $fh = 'IO::File'->new( ">$output") ;
+            my $fh = 'IO::File'->new( "$output", ">") ;
             ok &$Func("<$tmpDir1/a*.tmp>" => $fh, AutoClose => 1, @opts), '  UnCompressed ok' 
                 or diag $$Error ;
 
@@ -1518,9 +1510,9 @@ sub run
         {
             my ($send, $get) = @$data ;
 
-            my $fh1 = 'IO::File'->new( "< $file1") ;
-            my $fh2 = 'IO::File'->new( "< $file2") ;
-            my $fh3 = 'IO::File'->new( "< $file3") ;
+            my $fh1 = 'IO::File'->new( "$file1", "<") ;
+            my $fh2 = 'IO::File'->new( "$file2", "<") ;
+            my $fh3 = 'IO::File'->new( "$file3", "<") ;
 
             title "$send";
             my($copy);
