@@ -5,6 +5,7 @@ $VERSION = '1.02_02';
 BEGIN {
   push @INC, './lib';
 }
+use kurila;
 use strict ;
 
 sub DEFAULT_ON  () { 1 }
@@ -108,7 +109,7 @@ sub valueWalk
 sub orderValues
 {
     my $index = 0;
-    foreach my $ver ( sort { $a <=> $b } keys %v_list ) {
+    foreach my $ver ( sort { $a <+> $b } keys %v_list ) {
         foreach my $name (@{ $v_list{$ver} } ) {
 	    $ValueToName{ $index } = [ uc $name, $ver ] ;
 	    $NameToValue{ uc $name } = $index ++ ;
@@ -155,7 +156,7 @@ sub mkRange
     my $i ;
 
 
-    for ($i = 1 ; $i < @a; ++ $i) {
+    for ($i = 1 ; $i +< @a; ++ $i) {
       	$out[$i] = ".."
           if $a[$i] == $a[$i - 1] + 1 && $a[$i] + 1 == $a[$i + 1] ;
     }
@@ -173,7 +174,7 @@ sub printTree
     my $prefix = shift ;
     my ($k, $v) ;
 
-    my $max = (sort {$a <=> $b} map { length $_ } keys %$tre)[-1] ;
+    my $max = (sort {$a <+> $b} map { length $_ } keys %$tre)[-1] ;
     my @keys = sort keys %$tre ;
 
     while ($k = shift @keys) {
@@ -207,10 +208,10 @@ sub printTree
 
 ###########################################################################
 
-sub mkHexOct
+sub mkHex
 {
-    my ($f, $max, @a) = @_ ;
-    my $mask = "\x00" x $max ;
+    my ($max, @a) = @_ ;
+    my $mask = "\x[00]" x $max;
     my $string = "" ;
 
     foreach (@a) {
@@ -218,26 +219,9 @@ sub mkHexOct
     }
 
     foreach (unpack("C*", $mask)) {
-        if ($f eq 'x') {
-            $string .= '\x' . sprintf("%2.2x", $_)
-        }
-        else {
-            $string .= '\\' . sprintf("%o", $_)
-        }
+        $string .= sprintf("%2.2x", $_);
     }
-    return $string ;
-}
-
-sub mkHex
-{
-    my($max, @a) = @_;
-    return mkHexOct("x", $max, @a);
-}
-
-sub mkOct
-{
-    my($max, @a) = @_;
-    return mkHexOct("o", $max, @a);
+    return "\\x[$string]";
 }
 
 ###########################################################################
@@ -250,9 +234,9 @@ if (@ARGV && $ARGV[0] eq "tree")
 
 unlink "warnings.h";
 unlink "lib/warnings.pm";
-open(WARN, ">warnings.h") || die "Can't create warnings.h: $!\n";
+open(WARN, ">", "warnings.h") || die "Can't create warnings.h: $!\n";
 binmode WARN;
-open(PM, ">lib/warnings.pm") || die "Can't create lib/warnings.pm: $!\n";
+open(PM, ">", "lib/warnings.pm") || die "Can't create lib/warnings.pm: $!\n";
 binmode PM;
 
 print WARN <<'EOM' ;
@@ -293,7 +277,7 @@ $index = $offset ;
 valueWalk ($tree) ;
 my $index = orderValues();
 
-die <<EOM if $index > 255 ;
+die <<EOM if $index +> 255 ;
 Too many warnings categories -- max is 255
     rewrite packWARN* & unpackWARN* macros 
 EOM
@@ -305,7 +289,7 @@ my $warn_size = int($index / 8) + ($index % 8 != 0) ;
 
 my $k ;
 my $last_ver = 0;
-foreach $k (sort { $a <=> $b } keys %ValueToName) {
+foreach $k (sort { $a <+> $b } keys %ValueToName) {
     my ($name, $version) = @{ $ValueToName{$k} };
     print WARN "\n/* Warnings Categories added in Perl $version */\n\n"
         if $last_ver != $version ;
@@ -366,8 +350,8 @@ EOM
 
 close WARN ;
 
-while (<DATA>) {
-    last if /^KEYWORDS$/ ;
+while ( ~< *DATA) {
+    last if m/^KEYWORDS$/ ;
     print PM $_ ;
 }
 
@@ -375,7 +359,7 @@ while (<DATA>) {
 
 $last_ver = 0;
 print PM "our %Offsets = (\n" ;
-foreach my $k (sort { $a <=> $b } keys %ValueToName) {
+foreach my $k (sort { $a <+> $b } keys %ValueToName) {
     my ($name, $version) = @{ $ValueToName{$k} };
     $name = lc $name;
     $k *= 2 ;
@@ -394,7 +378,7 @@ print PM "our %Bits = (\n" ;
 foreach $k (sort keys  %list) {
 
     my $v = $list{$k} ;
-    my @list = sort { $a <=> $b } @$v ;
+    my @list = sort { $a <+> $b } @$v ;
 
     print PM tab(4, "    '$k'"), '=> "',
 		# mkHex($warn_size, @list),
@@ -408,7 +392,7 @@ print PM "our %DeadBits = (\n" ;
 foreach $k (sort keys  %list) {
 
     my $v = $list{$k} ;
-    my @list = sort { $a <=> $b } @$v ;
+    my @list = sort { $a <+> $b } @$v ;
 
     print PM tab(4, "    '$k'"), '=> "',
 		# mkHex($warn_size, @list),
@@ -420,7 +404,7 @@ print PM "  );\n\n" ;
 print PM 'our $NONE     = "', ('\0' x $warn_size) , "\";\n" ;
 print PM 'our $LAST_BIT = ' . "$index ;\n" ;
 print PM 'our $BYTES    = ' . "$warn_size ;\n" ;
-while (<DATA>) {
+while ( ~< *DATA) {
     print PM $_ ;
 }
 
@@ -440,7 +424,7 @@ our $VERSION = '1.06';
 
 # Verify that we're called correctly so that warnings will work.
 # see also strict.pm.
-unless ( __FILE__ =~ /(^|[\/\\])\Q${\__PACKAGE__}\E\.pmc?$/ ) {
+unless ( __FILE__ =~ m/(^|[\/\\])\Q${\__PACKAGE__}\E\.pmc?$/ ) {
     my (undef, $f, $l) = caller;
     die("Incorrect use of pragma '${\__PACKAGE__}' at $f line $l.\n");
 }
@@ -712,7 +696,7 @@ sub __chk
 
     if ($isobj) {
         while (do { { package DB; $pkg = (caller($i++))[0] } } ) {
-            last unless @DB::args && $DB::args[0] =~ /^$category=/ ;
+            last unless @DB::args && $DB::args[0] =~ m/^$category=/ ;
         }
 	$i -= 2 ;
     }
